<?php      
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'organizing-pro'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '',
    'ABeeZee' => 'ABeeZee',
    'Abel' => 'Abel',
    'Abril Fatface' => 'Abril Fatface',
    'Aclonica' => 'Aclonica',
    'Acme' => 'Acme',
    'Actor' => 'Actor',
    'Adamina' => 'Adamina',
    'Advent Pro' => 'Advent Pro',
    'Aguafina Script' => 'Aguafina Script',
    'Akronim' => 'Akronim',
    'Aladin' => 'Aladin',
    'Aldrich' => 'Aldrich',
    'Alegreya' => 'Alegreya',
    'Alegreya Sans SC' => 'Alegreya Sans SC',
    'Alegreya SC' => 'Alegreya SC',
    'Alex Brush' => 'Alex Brush',
    'Alef' => 'Alef',
    'Alfa Slab One' => 'Alfa Slab One',
    'Alice' => 'Alice',
    'Alike' => 'Alike',
    'Alike Angular' => 'Alike Angular',
    'Allan' => 'Allan',
    'Allerta' => 'Allerta',
    'Allerta Stencil' => 'Allerta Stencil',
    'Allura' => 'Allura',
    'Almendra' => 'Almendra',
    'Almendra Display' => 'Almendra Display',
    'Almendra SC' => 'Almendra SC',
    'Amiri' => 'Amiri',
    'Amarante' => 'Amarante',
    'Amaranth' => 'Amaranth',
    'Amatic SC' => 'Amatic SC',
    'Amethysta' => 'Amethysta',
    'Amita' => 'Amita',
    'Anaheim' => 'Anaheim',
    'Andada' => 'Andada',
    'Andika' => 'Andika',
    'Annie Use Your Telescope' => 'Annie Use Your Telescope',
    'Anonymous Pro' => 'Anonymous Pro',
    'Antic' => 'Antic',
    'Antic Didone' => 'Antic Didone',
    'Antic Slab' => 'Antic Slab',
    'Anton' => 'Anton',
    'Angkor' => 'Angkor',
    'Arapey' => 'Arapey',
    'Arbutus' => 'Arbutus',
    'Arbutus Slab' => 'Arbutus Slab',
    'Architects Daughter' => 'Architects Daughter',
    'Archivo White' => 'Archivo White',
    'Archivo Narrow' => 'Archivo Narrow',
    'Arial' => 'Arial',
    'Arimo' => 'Arimo',
    'Arya' => 'Arya',
    'Arizonia' => 'Arizonia',
    'Armata' => 'Armata',
    'Artifika' => 'Artifika',
    'Arvo' => 'Arvo',
    'Asar' => 'Asar',
    'Asap' => 'Asap',
    'Asset' => 'Asset',
    'Astloch' => 'Astloch',
    'Asul' => 'Asul',
    'Atomic Age' => 'Atomic Age',
    'Aubrey' => 'Aubrey',
    'Audiowide' => 'Audiowide',
    'Autour One' => 'Autour One',
    'Average' => 'Average',
    'Average Sans' => 'Average Sans',
    'Averia Gruesa Libre' => 'Averia Gruesa Libre',
    'Averia Libre' => 'Averia Libre',
    'Averia Sans Libre' => 'Averia Sans Libre',
    'Averia Serif Libre' => 'Averia Serif Libre',
    'Battambang' => 'Battambang',
    'Bad Script' => 'Bad Script',
    'Bayon' => 'Bayon',
    'Balthazar' => 'Balthazar',
    'Bangers' => 'Bangers',
    'Basic' => 'Basic',
    'Baumans' => 'Baumans',
    'Belgrano' => 'Belgrano',
    'Belleza' => 'Belleza',
    'BenchNine' => 'BenchNine',
    'Bentham' => 'Bentham',
    'Berkshire Swash' => 'Berkshire Swash',
    'Bevan' => 'Bevan',
    'Bigelow Rules' => 'Bigelow Rules',
    'Bigshot One' => 'Bigshot One',
    'Bilbo' => 'Bilbo',
    'Bilbo Swash Caps' => 'Bilbo Swash Caps',
    'Biryani' => 'Biryani',
    'Bitter' => 'Bitter',
    'White Ops One' => 'White Ops One',
    'Bokor' => 'Bokor',
    'Bonbon' => 'Bonbon',
    'Boogaloo' => 'Boogaloo',
    'Bowlby One' => 'Bowlby One',
    'Bowlby One SC' => 'Bowlby One SC',
    'Brawler' => 'Brawler',
    'Bree Serif' => 'Bree Serif',
    'Bubblegum Sans' => 'Bubblegum Sans',
    'Bubbler One' => 'Bubbler One',
    'Buda' => 'Buda',
    'Buenard' => 'Buenard',
    'Butcherman' => 'Butcherman',
    'Butcherman Caps' => 'Butcherman Caps',
    'Butterfly Kids' => 'Butterfly Kids',
    'Cabin' => 'Cabin',
    'Cabin Condensed' => 'Cabin Condensed',
    'Cabin Sketch' => 'Cabin Sketch',
    'Cabin' => 'Cabin',
    'Caesar Dressing' => 'Caesar Dressing',
    'Cagliostro' => 'Cagliostro',
    'Calligraffitti' => 'Calligraffitti',
    'Cambay' => 'Cambay',
    'Cambo' => 'Cambo',
    'Candal' => 'Candal',
    'Cantarell' => 'Cantarell',
    'Cantata One' => 'Cantata One',
    'Cantora One' => 'Cantora One',
    'Capriola' => 'Capriola',
    'Cardo' => 'Cardo',
    'Carme' => 'Carme',
    'Carrois Gothic' => 'Carrois Gothic',
    'Carrois Gothic SC' => 'Carrois Gothic SC',
    'Carter One' => 'Carter One',
    'Caveat' => 'Caveat',
    'Caveat Brush' => 'Caveat Brush',
    'Catamaran' => 'Catamaran',
    'Caudex' => 'Caudex',
    'Cedarville Cursive' => 'Cedarville Cursive',
    'Ceviche One' => 'Ceviche One',
    'Changa One' => 'Changa One',
    'Chango' => 'Chango',
    'Chau Philomene One' => 'Chau Philomene One',
    'Chenla' => 'Chenla',
    'Chela One' => 'Chela One',
    'Chelsea Market' => 'Chelsea Market',
    'Cherry Cream Soda' => 'Cherry Cream Soda',
    'Cherry Swash' => 'Cherry Swash',
    'Chewy' => 'Chewy',
    'Chicle' => 'Chicle',
    'Chivo' => 'Chivo',
    'Chonburi' => 'Chonburi',
    'Cinzel' => 'Cinzel',
    'Cinzel Decorative' => 'Cinzel Decorative',
    'Clicker Script' => 'Clicker Script',
    'Coda' => 'Coda',
    'Codystar' => 'Codystar',
    'Combo' => 'Combo',
    'Comfortaa' => 'Comfortaa',
    'Coming Soon' => 'Coming Soon',
    'Condiment' => 'Condiment',
    'Content' => 'Content',
    'Contrail One' => 'Contrail One',
    'Convergence' => 'Convergence',
    'Cookie' => 'Cookie',
    'Comic Sans MS' => 'Comic Sans MS',
    'Copse' => 'Copse',
    'Corben' => 'Corben',
    'Courgette' => 'Courgette',
    'Cousine' => 'Cousine',
    'Coustard' => 'Coustard',
    'Covered By Your Grace' => 'Covered By Your Grace',
    'Crafty Girls' => 'Crafty Girls',
    'Creepster' => 'Creepster',
    'Creepster Caps' => 'Creepster Caps',
    'Crete Round' => 'Crete Round',
    'Crimson' => 'Crimson',
    'Croissant One' => 'Croissant One',
    'Crushed' => 'Crushed',
    'Cuprum' => 'Cuprum',
    'Cutive' => 'Cutive',
    'Cutive Mono' => 'Cutive Mono',
    'Damion' => 'Damion',
    'Dangrek' => 'Dangrek',
    'Dancing Script' => 'Dancing Script',
    'Dawning of a New Day' => 'Dawning of a New Day',
    'Days One' => 'Days One',
    'Dekko' => 'Dekko',
    'Delius' => 'Delius',
    'Delius Swash Caps' => 'Delius Swash Caps',
    'Delius Unicase' => 'Delius Unicase',
    'Della Respira' => 'Della Respira',
    'Denk One' => 'Denk One',
    'Devonshire' => 'Devonshire',
    'Dhurjati' => 'Dhurjati',
    'Didact Gothic' => 'Didact Gothic',
    'Diplomata' => 'Diplomata',
    'Diplomata SC' => 'Diplomata SC',
    'Domine' => 'Domine',
    'Donegal One' => 'Donegal One',
    'Doppio One' => 'Doppio One',
    'Dorsa' => 'Dorsa',
    'Dosis' => 'Dosis',
    'Dr Sugiyama' => 'Dr Sugiyama',
    'Droid Sans' => 'Droid Sans',
    'Droid Sans Mono' => 'Droid Sans Mono',
    'Droid Serif' => 'Droid Serif',
    'Duru Sans' => 'Duru Sans',
    'Dynalight' => 'Dynalight',
    'EB Garamond' => 'EB Garamond',
    'Eczar' => 'Eczar',
    'Eagle Lake' => 'Eagle Lake',
    'Eater' => 'Eater',
    'Eater Caps' => 'Eater Caps',
    'Economica' => 'Economica',
    'Ek Mukta' => 'Ek Mukta',
    'Electrolize' => 'Electrolize',
    'Elsie' => 'Elsie',
    'Elsie Swash Caps' => 'Elsie Swash Caps',
    'Emblema One' => 'Emblema One',
    'Emilys Candy' => 'Emilys Candy',
    'Engagement' => 'Engagement',
    'Englebert' => 'Englebert',
    'Enriqueta' => 'Enriqueta',
    'Erica One' => 'Erica One',
    'Esteban' => 'Esteban',
    'Euphoria Script' => 'Euphoria Script',
    'Ewert' => 'Ewert',
    'Exo' => 'Exo',
    'Exo 2' => 'Exo 2',
    'Expletus Sans' => 'Expletus Sans',
    'Fanwood Text' => 'Fanwood Text',
    'Fascinate' => 'Fascinate',
    'Fascinate Inline' => 'Fascinate Inline',
    'Fasthand' => 'Fasthand',
    'Faster One' => 'Faster One',
    'Federant' => 'Federant',
    'Federo' => 'Federo',
    'Felipa' => 'Felipa',
    'Fenix' => 'Fenix',
    'Finger Paint' => 'Finger Paint',
    'Fira Mono' => 'Fira Mono',
    'Fira Sans' => 'Fira Sans',
    'Fjalla One' => 'Fjalla One',
    'Fjord One' => 'Fjord One',
    'Flamenco' => 'Flamenco',
    'Flavors' => 'Flavors',
    'Fondamento' => 'Fondamento',
    'Fontdiner Swanky' => 'Fontdiner Swanky',
    'Forum' => 'Forum',
    'Francois One' => 'Francois One',
    'FreeSans' => 'FreeSans',

    'Freckle Face' => 'Freckle Face',
    'Fredericka the Great' => 'Fredericka the Great',
    'Fredoka One' => 'Fredoka One',
    'Fresca' => 'Fresca',
    'Freehand' => 'Freehand',
    'Frijole' => 'Frijole',
    'Fruktur' => 'Fruktur',
    'Fugaz One' => 'Fugaz One',
    'Gafata' => 'Gafata',
    'Galdeano' => 'Galdeano',
    'Galindo' => 'Galindo',
    'Gentium Basic' => 'Gentium Basic',
    'Gentium Book Basic' => 'Gentium Book Basic',
    'Geo' => 'Geo',
    'Georgia' => 'Georgia',
    'Geostar' => 'Geostar',
    'Geostar Fill' => 'Geostar Fill',
    'Germania One' => 'Germania One',
    'Gilda Display' => 'Gilda Display',
    'Give You Glory' => 'Give You Glory',
    'Glass Antiqua' => 'Glass Antiqua',
    'Glegoo' => 'Glegoo',
    'Gloria Hallelujah' => 'Gloria Hallelujah',
    'Goblin One' => 'Goblin One',
    'Gochi Hand' => 'Gochi Hand',
    'Gorditas' => 'Gorditas',
    'Gurajada' => 'Gurajada',
    'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
    'Graduate' => 'Graduate',
    'Grand Hotel' => 'Grand Hotel',
    'Gravitas One' => 'Gravitas One',
    'Great Vibes' => 'Great Vibes',
    'Griffy' => 'Griffy',
    'Gruppo' => 'Gruppo',
    'Gudea' => 'Gudea',
    'Gidugu' => 'Gidugu',
    'GFS Didot' => 'GFS Didot',
    'GFS Neohellenic' => 'GFS Neohellenic',
    'Habibi' => 'Habibi',
    'Hammersmith One' => 'Hammersmith One',
    'Halant' => 'Halant',
    'Hanalei' => 'Hanalei',
    'Hanalei Fill' => 'Hanalei Fill',
    'Handlee' => 'Handlee',
    'Hanuman' => 'Hanuman',
    'Happy Monkey' => 'Happy Monkey',
    'Headland One' => 'Headland One',
    'Henny Penny' => 'Henny Penny',
    'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
    'Hind' => 'Hind',
    'Hind Siliguri' => 'Hind Siliguri',
    'Hind Vadodara' => 'Hind Vadodara',
    'Holtwood One SC' => 'Holtwood One SC',
    'Homemade Apple' => 'Homemade Apple',
    'Homenaje' => 'Homenaje',
    'IM Fell' => 'IM Fell',
    'Itim' => 'Itim',
    'Iceberg' => 'Iceberg',
    'Iceland' => 'Iceland',
    'Imprima' => 'Imprima',
    'Inconsolata' => 'Inconsolata',
    'Inder' => 'Inder',
    'Indie Flower' => 'Indie Flower',
    'Inknut Antiqua' => 'Inknut Antiqua',
    'Inika' => 'Inika',
    'Irish Growler' => 'Irish Growler',
    'Istok Web' => 'Istok Web',
    'Italiana' => 'Italiana',
    'Italianno' => 'Italianno',
    'Jacques Francois' => 'Jacques Francois',
    'Jacques Francois Shadow' => 'Jacques Francois Shadow',
    'Jim Nightshade' => 'Jim Nightshade',
    'Jockey One' => 'Jockey One',
    'Jaldi' => 'Jaldi',
    'Jolly Lodger' => 'Jolly Lodger',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Slab' => 'Josefin Slab',
    'Joti One' => 'Joti One',
    'Judson' => 'Judson',
    'Julee' => 'Julee',
    'Julius Sans One' => 'Julius Sans One',
    'Junge' => 'Junge',
    'Jura' => 'Jura',
    'Just Another Hand' => 'Just Another Hand',
    'Just Me Again Down Here' => 'Just Me Again Down Here',
    'Kadwa' => 'Kadwa',
    'Kdam Thmor' => 'Kdam Thmor',
    'Kalam' => 'Kalam', 
    'Kameron' => 'Kameron',
    'Kantumruy' => 'Kantumruy',
    'Karma' => 'Karma',
    'Karla' => 'Karla',
    'Kaushan Script' => 'Kaushan Script',
    'Kavoon' => 'Kavoon',
    'Keania One' => 'Keania One',
    'Kelly Slab' => 'Kelly Slab',
    'Kenia' => 'Kenia',
    'Khand' => 'Khand',
    'Khmer' => 'Khmer',
    'Khula' => 'Khula',
    'Kite One' => 'Kite One',
    'Knewave' => 'Knewave',
    'Kotta One' => 'Kotta One',
    'Kranky' => 'Kranky',
    'Kreon' => 'Kreon',
    'Kristi' => 'Kristi',
    'Koulen' => 'Koulen',
    'Krona One' => 'Krona One',
    'Kurale' => 'Kurale',
    'Lakki Reddy' => 'Lakki Reddy',
    'La Belle Aurore' => 'La Belle Aurore',
    'Lancelot' => 'Lancelot',
    'Laila' => 'Laila',
    'Lato' => 'Lato',
    'Lateef' => 'Lateef',
    'League Script' => 'League Script',
    'Leckerli One' => 'Leckerli One',
    'Ledger' => 'Ledger',
    'Lekton' => 'Lekton',
    'Lemon' => 'Lemon',

    'Libre Baskerville' => 'Libre Baskerville',
    'Life Savers' => 'Life Savers',
    'Lilita One' => 'Lilita One',
    'Limelight' => 'Limelight',
    'Linden Hill' => 'Linden Hill',
    'Lobster' => 'Lobster',
    'Lobster Two' => 'Lobster Two',
    'Londrina Outline' => 'Londrina Outline',
    'Londrina Shadow' => 'Londrina Shadow',
    'Londrina Sketch' => 'Londrina Sketch',
    'Londrina Solid' => 'Londrina Solid',
    'Lora' => 'Lora',
    'Love Ya Like A Sister' => 'Love Ya Like A Sister',
    'Loved by the King' => 'Loved by the King',
    'Lovers Quarrel' => 'Lovers Quarrel',
    'Lucida Sans Unicode' => 'Lucida Sans Unicode',
    'Luckiest Guy' => 'Luckiest Guy',
    'Lusitana' => 'Lusitana',
    'Lustria' => 'Lustria',
    'Macondo' => 'Macondo',
    'Macondo Swash Caps' => 'Macondo Swash Caps',
    'Magra' => 'Magra',
    'Maiden Orange' => 'Maiden Orange',
    'Mallanna' => 'Mallanna',
    'Mandali' => 'Mandali',
    'Mako' => 'Mako',
    'Marcellus' => 'Marcellus',
    'Marcellus SC' => 'Marcellus SC',
    'Marck Script' => 'Marck Script',
    'Margarine' => 'Margarine',
    'Marko One' => 'Marko One',
    'Marmelad' => 'Marmelad',
    'Marvel' => 'Marvel',
    'Martel' => 'Martel',
    'Martel Sans' => 'Martel Sans',
    'Mate' => 'Mate',
    'Mate SC' => 'Mate SC',
    'Maven Pro' => 'Maven Pro',
    'McLaren' => 'McLaren',
    'Meddon' => 'Meddon',
    'MedievalSharp' => 'MedievalSharp',
    'Medula One' => 'Medula One',
    'Megrim' => 'Megrim',
    'Meie Script' => 'Meie Script',
    'Merienda' => 'Merienda',
    'Merienda One' => 'Merienda One',
    'Merriweather' => 'Merriweather',
    'Metal' => 'Metal',
    'Metal Mania' => 'Metal Mania',
    'Metamorphous' => 'Metamorphous',
    'Metrophobic' => 'Metrophobic',
    'Michroma' => 'Michroma',
    'Milonga' => 'Milonga',
    'Miltonian' => 'Miltonian',
    'Miltonian Tattoo' => 'Miltonian Tattoo',
    'Miniver' => 'Miniver',
    'Miss Fajardose' => 'Miss Fajardose',
    'Miss Saint Delafield' => 'Miss Saint Delafield',
    'Modak' => 'Modak',
    'Modern Antiqua' => 'Modern Antiqua',
    'Molengo' => 'Molengo',
    'Molle' => 'Molle',
    'Moulpali' => 'Moulpali',
    'Monda' => 'Monda',
    'Monofett' => 'Monofett',
    'Monoton' => 'Monoton',
    'Monsieur La Doulaise' => 'Monsieur La Doulaise',
    'Montaga' => 'Montaga',
    'Montez' => 'Montez',
    'Montserrat' => 'Montserrat',
    'Montserrat Alternates' => 'Montserrat Alternates',
    'Montserrat Subrayada' => 'Montserrat Subrayada',
    'Mountains of Christmas' => 'Mountains of Christmas',
    'Mouse Memoirs' => 'Mouse Memoirs',
    'Moul' => 'Moul',
    'Mr Bedford' => 'Mr Bedford',
    'Mr Bedfort' => 'Mr Bedfort',
    'Mr Dafoe' => 'Mr Dafoe',
    'Mr De Haviland' => 'Mr De Haviland',
    'Mrs Saint Delafield' => 'Mrs Saint Delafield',
    'Mrs Sheppards' => 'Mrs Sheppards',
    'Muli' => 'Muli',
    'Mystery Quest' => 'Mystery Quest',
    'Neucha' => 'Neucha',
    'Neuton' => 'Neuton',
    'New Rocker' => 'New Rocker',
    'News Cycle' => 'News Cycle',
    'Niconne' => 'Niconne',
    'Nixie One' => 'Nixie One',
    'Nobile' => 'Nobile',
    'Nokora' => 'Nokora',
    'Norican' => 'Norican',
    'Nosifer' => 'Nosifer',
    'Nosifer Caps' => 'Nosifer Caps',
    'Nova Mono' => 'Nova Mono',
    'Noticia Text' => 'Noticia Text',
    'Noto Sans' => 'Noto Sans',
    'Noto Serif' => 'Noto Serif',
    'Nova Round' => 'Nova Round',
    'Numans' => 'Numans',
    'Nunito' => 'Nunito',
    'NTR' => 'NTR',
    'Offside' => 'Offside',
    'Oldenburg' => 'Oldenburg',
    'Oleo Script' => 'Oleo Script',
    'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
    'Open Sans' => 'Open Sans',
    'Open Sans Condensed' => 'Open Sans Condensed',
    'Oranienbaum' => 'Oranienbaum',
    'Orbitron' => 'Orbitron',
    'Odor Mean Chey' => 'Odor Mean Chey',
    'Oregano' => 'Oregano',
    'Orienta' => 'Orienta',
    'Original Surfer' => 'Original Surfer',
    'Oswald' => 'Oswald',
    'Over the Rainbow' => 'Over the Rainbow',
    'Overlock' => 'Overlock',
    'Overlock SC' => 'Overlock SC',
    'Ovo' => 'Ovo',
    'Oxygen' => 'Oxygen',
    'Oxygen Mono' => 'Oxygen Mono',
    'Palanquin Dark' => 'Palanquin Dark',
    'Peddana' => 'Peddana',
    'Poppins' => 'Poppins',
    'PT Mono' => 'PT Mono',
    'PT Sans' => 'PT Sans',
    'PT Sans Caption' => 'PT Sans Caption',
    'PT Sans Narrow' => 'PT Sans Narrow',
    'PT Serif' => 'PT Serif',
    'PT Serif Caption' => 'PT Serif Caption',
    'Pacifico' => 'Pacifico',
    'Paprika' => 'Paprika',
    'Parisienne' => 'Parisienne',
    'Passero One' => 'Passero One',
    'Passion One' => 'Passion One',
    'Patrick Hand' => 'Patrick Hand',
    'Patrick Hand SC' => 'Patrick Hand SC',
    'Patua One' => 'Patua One',
    'Paytone One' => 'Paytone One',
    'Peralta' => 'Peralta',
    'Permanent Marker' => 'Permanent Marker',
    'Petit Formal Script' => 'Petit Formal Script',
    'Petrona' => 'Petrona',
    'Philosopher' => 'Philosopher',
    'Piedra' => 'Piedra',
    'Pinyon Script' => 'Pinyon Script',
    'Pirata One' => 'Pirata One',
    'Plaster' => 'Plaster',
    'Palatino Linotype' => 'Palatino Linotype',
    'Play' => 'Play',
    'Playball' => 'Playball',
    'Playfair Display' => 'Playfair Display',
    'Playfair Display SC' => 'Playfair Display SC',
    'Podkova' => 'Podkova',
    'Poiret One' => 'Poiret One',
    'Poller One' => 'Poller One',
    'Poly' => 'Poly',
    'Pompiere' => 'Pompiere',
    'Pontano Sans' => 'Pontano Sans',
    'Port Lligat Sans' => 'Port Lligat Sans',
    'Port Lligat Slab' => 'Port Lligat Slab',
    'Prata' => 'Prata',
    'Pragati Narrow' => 'Pragati Narrow',
    'Preahvihear' => 'Preahvihear',
    'Press Start 2P' => 'Press Start 2P',
    'Princess Sofia' => 'Princess Sofia',
    'Prociono' => 'Prociono',
    'Prosto One' => 'Prosto One',
    'Puritan' => 'Puritan',
    'Purple Purse' => 'Purple Purse',
    'Quando' => 'Quando',
    'Quantico' => 'Quantico',
    'Quattrocento' => 'Quattrocento',
    'Quattrocento Sans' => 'Quattrocento Sans',
    'Questrial' => 'Questrial',
    'Quicksand' => 'Quicksand',
    'Quintessential' => 'Quintessential',
    'Qwigley' => 'Qwigley',
    'Racing Sans One' => 'Racing Sans One',
    'Radley' => 'Radley',
    'Rajdhani' => 'Rajdhani',
    'Raleway Dots' => 'Raleway Dots',
    'Raleway' => 'Raleway',
    'Rambla' => 'Rambla',
    'Ramabhadra' => 'Ramabhadra',
    'Ramaraja' => 'Ramaraja',
    'Rammetto One' => 'Rammetto One',
    'Ranchers' => 'Ranchers',
    'Rancho' => 'Rancho',
    'Ranga' => 'Ranga',
    'Ravi Prakash' => 'Ravi Prakash',
    'Rationale' => 'Rationale',
    'Redressed' => 'Redressed',
    'Reenie Beanie' => 'Reenie Beanie',
    'Revalia' => 'Revalia',
    'Rhodium Libre' => 'Rhodium Libre',
    'Ribeye' => 'Ribeye',
    'Ribeye Marrow' => 'Ribeye Marrow',
    'Righteous' => 'Righteous',
    'Risque' => 'Risque',
    'Roboto' => 'Roboto',
    'Roboto Condensed' => 'Roboto Condensed',
    'Roboto Mono' => 'Roboto Mono',
    'Roboto Slab' => 'Roboto Slab',
    'Rochester' => 'Rochester',
    'Rock Salt' => 'Rock Salt',
    'Rokkitt' => 'Rokkitt',
    'Romanesco' => 'Romanesco',
    'Ropa Sans' => 'Ropa Sans',
    'Rosario' => 'Rosario',
    'Rosarivo' => 'Rosarivo',
    'Rouge Script' => 'Rouge Script',
    'Rozha One' => 'Rozha One',
    'Rubik' => 'Rubik',
    'Rubik One' => 'Rubik One',
    'Rubik Mono One' => 'Rubik Mono One',
    'Ruda' => 'Ruda',
    'Rufina' => 'Rufina',
    'Ruge Boogie' => 'Ruge Boogie',
    'Ruluko' => 'Ruluko',
    'Rum Raisin' => 'Rum Raisin',
    'Ruslan Display' => 'Ruslan Display',
    'Russo One' => 'Russo One',
    'Ruthie' => 'Ruthie',
    'Rye' => 'Rye',
    'Sacramento' => 'Sacramento',
    'Sail' => 'Sail',
    'Salsa' => 'Salsa',
    'Sanchez' => 'Sanchez',
    'Sancreek' => 'Sancreek',
    'Sahitya' => 'Sahitya',
    'Sansita One' => 'Sansita One',
    'Sarpanch' => 'Sarpanch',
    'Sarina' => 'Sarina',
    'Satisfy' => 'Satisfy',
    'Scada' => 'Scada',
    'Scheherazade' => 'Scheherazade',
    'Schoolbell' => 'Schoolbell',
    'Seaweed Script' => 'Seaweed Script',
    'Sarala' => 'Sarala',
    'Sevillana' => 'Sevillana',
    'Seymour One' => 'Seymour One',
    'Shadows Into Light' => 'Shadows Into Light',
    'Shadows Into Light Two' => 'Shadows Into Light Two',
    'Shanti' => 'Shanti',
    'Share' => 'Share',
    'Share Tech' => 'Share Tech',
    'Share Tech Mono' => 'Share Tech Mono',
    'Shojumaru' => 'Shojumaru',
    'Short Stack' => 'Short Stack',
    'Sigmar One' => 'Sigmar One',
    'Suranna' => 'Suranna',
    'Suravaram' => 'Suravaram',
    'Suwannaphum' => 'Suwannaphum',
    'Signika' => 'Signika',
    'Signika Negative' => 'Signika Negative',
    'Simonetta' => 'Simonetta',
    'Siemreap' => 'Siemreap',
    'Sirin Stencil' => 'Sirin Stencil',
    'Six Caps' => 'Six Caps',
    'Skranji' => 'Skranji',
    'Slackey' => 'Slackey',
    'Smokum' => 'Smokum',
    'Smythe' => 'Smythe',
    'Sniglet' => 'Sniglet',
    'Snippet' => 'Snippet',
    'Snowburst One' => 'Snowburst One',
    'Sofadi One' => 'Sofadi One',
    'Sofia' => 'Sofia',
    'Sonsie One' => 'Sonsie One',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Source Code Pro' => 'Source Code Pro',
    'Source Sans Pro' => 'Source Sans Pro',
    'Special I am one' => 'Special I am one',
    'Spicy Rice' => 'Spicy Rice',
    'Spinnaker' => 'Spinnaker',
    'Spirax' => 'Spirax',
    'Squada One' => 'Squada One',
    'Sree Krushnadevaraya' => 'Sree Krushnadevaraya',
    'Stalemate' => 'Stalemate',
    'Stalinist One' => 'Stalinist One',
    'Stardos Stencil' => 'Stardos Stencil',
    'Stint Ultra Condensed' => 'Stint Ultra Condensed',
    'Stint Ultra Expanded' => 'Stint Ultra Expanded',
    'Stoke' => 'Stoke',
    'Stoke' => 'Stoke',
    'Strait' => 'Strait',
    'Sura' => 'Sura',
    'Sumana' => 'Sumana',
    'Sue Ellen Francisco' => 'Sue Ellen Francisco',
    'Sunshiney' => 'Sunshiney',
    'Supermercado One' => 'Supermercado One',
    'Swanky and Moo Moo' => 'Swanky and Moo Moo',
    'Syncopate' => 'Syncopate',
    'Symbol' => 'Symbol',
    'Timmana' => 'Timmana',
    'Taprom' => 'Taprom',
    'Tangerine' => 'Tangerine',
    'Tahoma' => 'Tahoma',
    'Teko' => 'Teko',
    'Telex' => 'Telex',
    'Tenali Ramakrishna' => 'Tenali Ramakrishna',
    'Tenor Sans' => 'Tenor Sans',
    'Terminal Dosis' => 'Terminal Dosis',
    'Terminal Dosis Light' => 'Terminal Dosis Light',
    'Text Me One' => 'Text Me One',
    'The Girl Next Door' => 'The Girl Next Door',
    'Tienne' => 'Tienne',
    'Tillana' => 'Tillana',
    'Tinos' => 'Tinos',
    'Titan One' => 'Titan One',
    'Titillium Web' => 'Titillium Web',
    'Trade Winds' => 'Trade Winds',
    'Trebuchet MS' => 'Trebuchet MS',
    'Trocchi' => 'Trocchi',
    'Trochut' => 'Trochut',
    'Trykker' => 'Trykker',
    'Tulpen One' => 'Tulpen One',
    'Ubuntu' => 'Ubuntu',
    'Ubuntu Condensed' => 'Ubuntu Condensed',
    'Ubuntu Mono' => 'Ubuntu Mono',
    'Ultra' => 'Ultra',
    'Uncial Antiqua' => 'Uncial Antiqua',
    'Underdog' => 'Underdog',
    'Unica One' => 'Unica One',
    'UnifrakturCook' => 'UnifrakturCook',
    'UnifrakturMaguntia' => 'UnifrakturMaguntia',
    'Unkempt' => 'Unkempt',
    'Unlock' => 'Unlock',
    'Unna' => 'Unna',
    'VT323' => 'VT323',
    'Vampiro One' => 'Vampiro One',
    'Varela' => 'Varela',
    'Varela Round' => 'Varela Round',
    'Vast Shadow' => 'Vast Shadow',
    'Vesper Libre' => 'Vesper Libre',
    'Verdana' => 'Verdana',
    'Vibur' => 'Vibur',
    'Vidaloka' => 'Vidaloka',
    'Viga' => 'Viga',
    'Voces' => 'Voces',
    'Volkhov' => 'Volkhov',
    'Vollkorn' => 'Vollkorn',
    'Voltaire' => 'Voltaire',
    'Waiting for the Sunrise' => 'Waiting for the Sunrise',
    'Wallpoet' => 'Wallpoet',
    'Walter Turncoat' => 'Walter Turncoat',
    'Warnes' => 'Warnes',
    'Wellfleet' => 'Wellfleet',
    'Wendy One' => 'Wendy One',
    'Wire One' => 'Wire One',
    'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
    'Yantramanav' => 'Yantramanav',
    'Yellowtail' => 'Yellowtail',
    'Yeseva One' => 'Yeseva One',
    'Yesteryear' => 'Yesteryear',
    'Zeyada' => 'Zeyada'
  );

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	
	$options = array();
	$imagepath =  get_template_directory_uri() . '/images/';

	
	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(	
			1 => array(
			'section_title'	=> 'Who We Are?',
			'menutitle'		=> 'section1',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '<p>Mauris vel elit enim. Integer gravida mauris non augue euismod, laoreet luctus libero hendrerit. Vivamus viverra nulla id purus porta rhoncus. <br />Morbi viverra malesuada luctus. </p>',
		),
		
			2 => array(
			'section_title'	=> '',
			'menutitle'		=> 'section2',
			'bgcolor' 		=> '#f7f6f6',
			'bgimage'		=> get_template_directory_uri().'/images/section2.jpg',
			'class'			=> '',
			'content'		=> '[column_content type="one_half"]&nbsp;[/column_content][column_content type="one_half_last"]<h2 class="section_title">Why Choose US</h2><p>Vivamus non lacus ut diam pharetra porttitor nec non dui. In et ex et orci ullamcorper rhoncus a nec lectus. Nullam laoreet, augue vitae eleifend vestibulum, orci nunc euismod magna, at iaculis purus nulla eu nunc. Quisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.</p>[space height="40px"][whychooseus icon="fas fa-star" title="" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." link=""][whychooseus icon="far fa-life-ring" title="" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." link=""][whychooseus icon="fas fa-pencil-alt" title="" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." link=""][whychooseus icon="fas fa-paint-brush" title="" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." link=""][space height="1px"][button name="READ MORE" align="left" link="" target="_self"][/column_content]',
		),
		

			3 => array(
			'section_title'	=> 'What is Organizing',
			'menutitle'		=> 'section3',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> get_template_directory_uri().'/images/section3.jpg',
			'class'			=> '',
			'content'		=> '
[column_content type="one_half"]
<p>Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.ss</p>
<p></p>
<p></p>
[accordion]
[accordion_content title="1. Awesome Design."]Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.[/accordion_content][accordion_content title="2. Premium Sliders."]Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.[/accordion_content][accordion_content title="3. Fully Responsive."]Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.[/accordion_content][accordion_content title="4. Great Shortcodes."]Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.[/accordion_content][accordion_content title="5. Well Documented."]Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur.[/accordion_content][/accordion][space height="1px"][button name="READ MORE" align="left" link="" target="_self"]
[/column_content]
[column_content type="one_half_last"]&nbsp;[/column_content]',
		),

 
			4 => array(
			'section_title'	=> 'Our Services',
			'menutitle'		=> 'section4',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '<p style="text-align:center;">Mauris vel elit enim. Integer gravida mauris non augue euismod, laoreet luctus libero hendrerit. Vivamus viverra nulla id purus porta rhoncus. <br />Morbi viverra malesuada luctus. </p>

[space height="30px"]

[servicesbox icon="fas fa-desktop" title="Web Design & Development" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." readmore="Read More" link="#"][servicesbox icon="fas fa-mobile-alt" title="Mobile Apps" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." readmore="Read More" link="#"][servicesbox icon="far fa-heart" title="Brand Design" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." readmore="Read More" link="#"][servicesbox icon="fas fa-bullhorn" title="Marketing" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." readmore="Read More" link="#"][servicesbox icon="fas fa-image" title="Facebook Ads" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." readmore="Read More" link="#"][servicesbox icon="fab fa-google" title="Google Adword" description="Euismod magna, at iaculis purus nulla eu nunc uisque volutpat lectus eu posuere blandit. Nunc non nulla consectetur." readmore="Read More" link="#"]

[clear]

[space height="30px"]

[button name="VIEW ALL SERVICES" align="center" link="#" target="_self"]
',
		),
		
			5 => array(
			'section_title'	=> '',
			'menutitle'		=> 'section5',
			'bgcolor' 		=> '#f7f6f6',
			'bgimage'		=> get_template_directory_uri().'/images/section5.jpg',
			'class'			=> '',
			'content'		=> '<div class="testimonial-bg"><h2 class="section_title">What Clients Said?</h2><div>[testimonials show="-1"]</div></div>',
		),
		

		6 => array(
			'section_title'	=> 'Latest News',
			'menutitle'		=> 'section6',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '<p style="text-align:center;">Mauris vel elit enim. Integer gravida mauris non augue euismod, laoreet luctus libero hendrerit. Vivamus viverra nulla id purus porta rhoncus. <br />Morbi viverra malesuada luctus. </p>
			
[latestposts show="3" catid=""]
[space height="20px"]
[button name="VIEW ALL POST" align="center" link="#" target="_self"]',
		),
		
		7 => array(
			'section_title'	=> 'Our Project',
			'menutitle'		=> 'section7',
			'bgcolor' 		=> '#e8edf3',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '<p style="text-align:center;">Mauris vel elit enim. Integer gravida mauris non augue euismod, laoreet luctus libero hendrerit. Vivamus viverra nulla id purus porta rhoncus. <br />Morbi viverra malesuada luctus. </p>
			
[photogallery filter="true" show="-1"]',
		),		


		8 => array(
			'section_title'	=> 'Our Client',
			'menutitle'		=> 'section8',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '<p style="text-align:center;">Mauris vel elit enim. Integer gravida mauris non augue euismod, laoreet luctus libero hendrerit. Vivamus viverra nulla id purus porta rhoncus. <br />Morbi viverra malesuada luctus. </p>
		
[space height="20px"]
			
[client_lists][client title="WORDPRESS" image="'.get_template_directory_uri().'/images/client-logo1.jpg" link="#"][client title="JQUERY" image="'.get_template_directory_uri().'/images/client-logo2.jpg" link="#"][client title="WOOCOMMERCE" image="'.get_template_directory_uri().'/images/client-logo3.jpg" link="#"][client title="BBPRESS" image="'.get_template_directory_uri().'/images/client-logo4.jpg" link="#"][client title="MY SQL" image="'.get_template_directory_uri().'/images/client-logo5.jpg" link="#"][/client_lists]',
		),			

		9 => array(
			'section_title'	=> '',
			'menutitle'		=> 'section9',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> get_template_directory_uri().'/images/section9.jpg',
			'class'			=> '',
			'content'		=> '<h2 class="section_title">Get In Touch</h2>
<p>Send us a message & we will be in touch</p>
[column_content type="one_half"] [contactform to_email="test@example.com" title="Get In Touch"][/column_content][column_content type="one_half_last"]&nbsp;[/column_content]',
		),
		
		10 => array(
			'section_title'	=> '',
			'menutitle'		=> 'section10',
			'bgcolor' 		=> '#ffa800',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '[column_content type="one_half"]<h2 class="section_title">Subscribe Newsletter</h2><p>There are many variations of passages of lorem there are many</p>[/column_content][column_content type="one_half_last"]<div><form class="newsletter-form"><input placeholder="Your e-mail" type="email"><input value="SUBSCRIBE" type="submit"></i></form></div>[/column_content]',
		),
	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'organizing-pro'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'organizing-pro'),
		'desc' => __('Upload your main logo here', 'organizing-pro'),
		'id' => 'logo',
		'class' => '',
//		'std'	=> get_template_directory_uri().'/images/logo.png',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('Change your custom logo height', 'organizing-pro'),
		'id' => 'logoheight',
		'std' => '55',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'organizing-pro'),		
		'desc'	=> __('Check To hide site title and description', 'organizing-pro'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> '');		
		
	$options[] = array(	
		'name' => __('Layout Option', 'organizing-pro'),		
		'desc'	=> __('Check To View Box Layout ', 'organizing-pro'),
		'id'	=> 'boxlayout',
		'type'	=> 'checkbox',
		'std'	=> '');
			
	$options[] = array(
		'name' => __('Sticky Header', 'organizing-pro'),
		'desc' => __('Check this to disable sticky header on scroll', 'organizing-pro'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(
		'name' => __('Header Top Social Icons', 'organizing-pro'),
		'desc' => __('Edit select social icons for header top', 'organizing-pro'),
		'id' => 'headersocial',
		'std' => '[social_area] 
[social icon="fab fa-facebook-f" link="#"] 
[social icon="fab fa-twitter" link="#"] 
[social icon="fab fa-google-plus-g" link="#"] 
[social icon="fab fa-linkedin-in" link="#"] 
[social icon="fas fa-rss" link="#"] 
[/social_area]',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Header Right Social Icons', 'organizing-pro'),
		'desc' => __('Edit select social icons for header menu right', 'organizing-pro'),
		'id' => 'headersocialright',
		'std' => '[social_area] 
[social icon="fab fa-facebook-f" link="#"] 
[social icon="fab fa-twitter" link="#"] 
[social icon="fab fa-google-plus-g" link="#"] 
[social icon="fab fa-linkedin-in" link="#"] 
[/social_area]',
		'type' => 'textarea');	
				
		
	$options[] = array(
		'name' => __('Header Top Info', 'organizing-pro'),
		'desc' => __('Edit header info from here. NOTE: Icon name should be in lowercase without space.(exa.phone) More social icons can be found at: https://fontawesome.com/icons/', 'organizing-pro'),
		'id' => 'headerinfo',
		'std' => '<i class="fas fa-phone-square"></i> +11 123 456 7890 <span class="phno"><a href="mailto:info@sitename.com"><i class="fas fa-envelope"></i>info@sitename.com</a></span>',
		'type' => 'textarea');		
		
			
	$options[] = array(
		'name' => __('Header top email and phone number strip', 'organizing-pro'),
		'desc' => __('Check this to enable header top strips', 'organizing-pro'),
		'id' => 'headtopstrip',
		'std' => '',
		'type' => 'checkbox');		
			
	$options[] = array(
		'name' => __('Disable Animation', 'organizing-pro'),
		'desc' => __('Check this to disable animation on scroll', 'organizing-pro'),
		'id' => 'scrollanimation',
		'std' => 'true',
		'type' => 'checkbox');		

	$options[] = array(
		'name' => __('Custom CSS', 'organizing-pro'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'organizing-pro'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
			
	// font family start 		
	$options[] = array(
		'name' => __('Font Faces', 'organizing-pro'),
		'desc' => __('Select font for the body text', 'organizing-pro'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'organizing-pro'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'organizing-pro'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for all heading tag.', 'organizing-pro'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for Section title', 'organizing-pro'),
		'id' => 'sectiontitlefontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );		
			
	$options[] = array(
		'desc' => __('Select font for Slide title', 'organizing-pro'),
		'id' => 'slidetitlefontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );	
		
	$options[] = array(
		'desc' => __('Select font for Slide Description', 'organizing-pro'),
		'id' => 'slidedesfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );	

		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'organizing-pro'),
		'desc' => __('Select font size for body text', 'organizing-pro'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '15px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'organizing-pro'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '31px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'organizing-pro'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '14px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'organizing-pro'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '30px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'organizing-pro'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );	

	$options[] = array(
		'desc' => __('Select h1 font size', 'organizing-pro'),
		'id' => 'h1fontsize',
		'std' => '30px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h2 font size', 'organizing-pro'),
		'id' => 'h2fontsize',
		'std' => '31px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h3 font size', 'organizing-pro'),
		'id' => 'h3fontsize',
		'std' => '18px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h4 font size', 'organizing-pro'),
		'id' => 'h4fontsize',
		'std' => '22px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h5 font size', 'organizing-pro'),
		'id' => 'h5fontsize',
		'std' => '18px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h6 font size', 'organizing-pro'),
		'id' => 'h6fontsize',
		'std' => '16px',
		'type' => 'select',
		'options' => $font_sizes);


	// font colors start

	$options[] = array(
		'name' => __('Site Colors Scheme', 'organizing-pro'),
		'desc' => __('Change the color scheme of hole site', 'organizing-pro'),
		'id' => 'colorscheme',
		'std' => '#ffa800',
		'type' => 'color');
		
	$options[] = array(	
		'name' => __('Font Colors', 'organizing-pro'),	
		'desc' => __('Select font color for the body text', 'organizing-pro'),
		'id' => 'bodyfontcolor',
		'std' => '#7c7c7c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'organizing-pro'),
		'id' => 'logofontcolor',
		'std' => '#383838',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for logo tagline', 'organizing-pro'),
		'id' => 'logotaglinecolor',
		'std' => '#151515',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for header top phone and email strip', 'organizing-pro'),
		'id' => 'headertopfontcolor',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select font color for header social icons', 'organizing-pro'),
		'id' => 'socialfontcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select Background color for header social icons', 'organizing-pro'),
		'id' => 'socialbgcolor',
		'std' => '#262626',
		'type' => 'color');

		
	$options[] = array(
		'desc' => __('Select font color for section title', 'organizing-pro'),
		'id' => 'sectitlecolor',
		'std' => '#101112',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for navigation', 'organizing-pro'),
		'id' => 'navfontcolor',
		'std' => '#282828',
		'type' => 'color');
		   
	$options[] = array(
		'desc' => __('Select font color for widget title', 'organizing-pro'),
		'id' => 'wdgttitleccolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'organizing-pro'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'organizing-pro'),
		'id' => 'footdesccolor',
		'std' => '#8b8a8a',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'organizing-pro'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'organizing-pro'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for links / anchor tags', 'organizing-pro'),
		'id' => 'linkhovercolor',
		'std' => '#272727',
		'type' => 'color');			

	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'organizing-pro'),
		'id' => 'sidebarfontcolor',
		'std' => '#78797c',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select font hover color for footer copyright links', 'organizing-pro'),
		'id' => 'copylinkshover',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h1 font color', 'organizing-pro'),
		'id' => 'h1fontcolor',
		'std' => '#272727',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select h2 font color', 'organizing-pro'),
		'id' => 'h2fontcolor',
		'std' => '#272727',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h3 font color', 'organizing-pro'),
		'id' => 'h3fontcolor',
		'std' => '#272727',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h4 font color', 'organizing-pro'),
		'id' => 'h4fontcolor',
		'std' => '#272727',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h5 font color', 'organizing-pro'),
		'id' => 'h5fontcolor',
		'std' => '#272727',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h6 font color', 'organizing-pro'),
		'id' => 'h6fontcolor',
		'std' => '#272727',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer social icons', 'organizing-pro'),
		'id' => 'footsocialcolor',
		'std' => '#c1c0c0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for gallery filter ', 'organizing-pro'),
		'id' => 'galleryfiltercolor',
		'std' => '#010101',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font hover color for gallery filter ', 'organizing-pro'),
		'id' => 'galleryfiltercolorhv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for photogallery title ', 'organizing-pro'),
		'id' => 'gallerytitlecolorhv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for latest post title', 'organizing-pro'),
		'id' => 'latestpoststtlcolor',
		'std' => '#262626',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for client testimonilas title', 'organizing-pro'),
		'id' => 'testimonialtitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for client testimonilas description', 'organizing-pro'),
		'id' => 'testimonialdescriptioncolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for sidebar widget box', 'organizing-pro'),
		'id' => 'widgetboxfontcolor',
		'std' => '#6e6d6d',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer recent posts', 'organizing-pro'),
		'id' => 'footerpoststitlecolor',
		'std' => '#8b8a8a',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for toggle menu on responsive', 'organizing-pro'),
		'id' => 'togglemenucolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for our skills counter', 'organizing-pro'),
		'id' => 'counterdesccolor',
		'std' => '#383838',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our skills title', 'organizing-pro'),
		'id' => 'countertitlecolor',
		'std' => '#262626',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font awesome icon color for our theme features section', 'organizing-pro'),
		'id' => 'fontawesomeiconcolor',
		'std' => '#272727',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font awesome icon color hover for our theme features section', 'organizing-pro'),
		'id' => 'fontawesomeiconcolorhv',
		'std' => '#ffffff',
		'type' => 'color');						

	$options[] = array(
		'desc' => __('Select font color for Why Choose Us Box ', 'organizing-pro'),
		'id' => 'whychoosecolor',
		'std' => '#888888',
		'type' => 'color');						
		
	// Background start			
	$options[] = array(
		'name' => __('Background Colors', 'organizing-pro'),		
		'desc' => __('Select background color for header', 'organizing-pro'),
		'id' => 'headerbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(		
		'desc' => __('Select background opacity color for header', 'organizing-pro'),
		'id' => 'headeropacity',
		'std' => '1',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));			


	$options[] = array(
		'desc' => __('Select background color for header top phone and email strip', 'organizing-pro'),
		'id' => 'headertopbgcolor',
		'std' => '#171819',
		'type' => 'color');	
			
	$options[] = array(
		'desc' => __('Select background color for header nav dropdown', 'organizing-pro'),
		'id' => 'navdpbgcolor',
		'std' => '#f7f6f6',
		'type' => 'color');	
		 
	$options[] = array(
		'desc' => __('Select background color Latest news boxes', 'organizing-pro'),
		'id' => 'newsbxbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for Post Date', 'organizing-pro'),
		'id' => 'postdtebgcolor',
		'std' => '#282828',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for footer', 'organizing-pro'),
		'id' => 'footerbgcolor',
		'std' => '#000000',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select background color for copyright section', 'organizing-pro'),
		'id' => 'copybgcolor',
		'std' => '#0c0c0c',
		'type' => 'color');	

	$options[] = array(		
		'desc' => __('Select background opacity color for footer Copyright', 'organizing-pro'),
		'id' => 'copybgopacity',
		'std' => '1',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));			

	$options[] = array(
		'desc' => __('Select background color for photogallery filter', 'organizing-pro'),
		'id' => 'galleryfilter',
		'std' => '#f1f1f1',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for client testimonials Box', 'organizing-pro'),
		'id' => 'testiboxbgcolor',
		'std' => '',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select background color for client testimonials Box border', 'organizing-pro'),
		'id' => 'testiboxbdcolor',
		'std' => '',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for client testimonials pager dots', 'organizing-pro'),
		'id' => 'testidotsbgcolor',
		'std' => '#000000',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for sidebar widget box', 'organizing-pro'),
		'id' => 'widgetboxbgcolor',
		'std' => '#F0EFEF',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for our skill bar', 'organizing-pro'),
		'id' => 'skillbarbgcolor',
		'std' => '#E0DFDF',
		'type' => 'color');	
		 
	$options[] = array(
		'desc' => __('Select background color for Our team social icon', 'organizing-pro'),
		'id' => 'teamsocialiconbg',
		'std' => '#ffffff',
		'type' => 'color');					

	$options[] = array(
		'desc' => __('Select background color for Our Team Box', 'organizing-pro'),
		'id' => 'ourteambgcolor',
		'std' => '#f3f3f3',
		'type' => 'color');			
		

	// Border colors			
	$options[] = array(	
		'name' => __('Border Colors', 'organizing-pro'),		
		'desc' => __('Select border color for sidebar li a', 'organizing-pro'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer title', 'organizing-pro'),
		'id' => 'footertitleborder',
		'std' => '#312d2e',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for top navigation dropdown li', 'organizing-pro'),
		'id' => 'navlibdcolor',
		'std' => '#333333',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for gallery filter', 'organizing-pro'),
		'id' => 'galleryfilterbdr',
		'std' => '#494949',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for section title underline', 'organizing-pro'),
		'id' => 'sectitleunderlinecolor',
		'std' => '#383838',
		'type' => 'color');	

	$options[] = array(			
		'desc' => __('Select border color for All images', 'organizing-pro'),
		'id' => 'allimagesborder',
		'std' => '#ebebeb',
		'type' => 'color');	
	
	$options[] = array(			
		'desc' => __('Select border color for right social icons', 'organizing-pro'),
		'id' => 'rightbdsocial',
		'std' => '#ebebeb',
		'type' => 'color');	

	$options[] = array(			
		'desc' => __('Select border color for Why Choose us icon', 'organizing-pro'),
		'id' => 'whychoosebdcolor',
		'std' => '#ebebeb',
		'type' => 'color');	

	$options[] = array(			
		'desc' => __('Select border color for Latest News', 'organizing-pro'),
		'id' => 'newsbdcolor',
		'std' => '#edeef0',
		'type' => 'color');	
	


	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'organizing-pro'),		
		'desc' => __('Select background hover color for default button', 'organizing-pro'),
		'id' => 'btnbghvcolor',
		'std' => '#202020',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color default button', 'organizing-pro'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for default button', 'organizing-pro'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');
		
		
	//Team Member Boxes CSS	
	$options[] = array(
		'name' => __('Team Member Section Colors', 'organizing-pro'),			
		'desc' => __('Select font color for team member box', 'organizing-pro'),
		'id' => 'teambxfontcolor',
		'std' => '#404040',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for team member designation', 'organizing-pro'),
		'id' => 'teamsocialcolor',
		'std' => '#727171',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select font color for our team hover', 'organizing-pro'),
		'id' => 'teamdesignationcolor',
		'std' => '#ffffff',
		'type' => 'color');	
	
	// Slider Caption colors
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'organizing-pro'),				
		'desc' => __('Select font color for slider title', 'organizing-pro'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');			
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'organizing-pro'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'organizing-pro'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '45px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'organizing-pro'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '15px',
		'options' => $font_sizes );
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'organizing-pro'),
		'desc' => __('Select background color for slider pager', 'organizing-pro'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for slider navigation arrows', 'organizing-pro'),
		'id' => 'sldarrowbg',
		'std' => '#000000',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select background opacity color for slider caption', 'organizing-pro'),
		'id' => 'slidercapbgpacity',
		'std' => '0.3',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));			
		
	$options[] = array(
		'desc' => __('Select Background color for slider caption', 'organizing-pro'),
		'id' => 'slidercapbg',
		'std' => '',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select background opacity color for header slider navigation arrows', 'organizing-pro'),
		'id' => 'sldarrowopacity',
		'std' => '0.7',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));			
		
	$options[] = array(
		'desc' => __('Select Border color for slider pager', 'organizing-pro'),
		'id' => 'sldpagehvbd',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for testimonials section', 'organizing-pro'),
		'id' => 'testimonialsexcerptlength',
		'std' => '35',
		'type' => 'text');


	$options[] = array(
		'desc' => __('If your content length in shortcode blog post.', 'furniture-pro'),
		'id' => 'newscontentlength',
		'std' => '17',
		'type' => 'text');

	$options[] = array(
		'desc' => __('Blog post page change text content lenth here ', 'furniture-pro'),
		'id' => 'blogpostpagecontent',
		'std' => '120',
		'type' => 'text');			


	$options[] = array(		
		'desc' => __('Select excerpt length for blog post', 'organizing-pro'),
		'id' => 'blogpostexcerptlength',
		'std' => '60',
		'type' => 'text');
		

	$options[] = array(		
		'desc' => __('Change for blog post Read more text', 'organizing-pro'),
		'id' => 'blogpostreadmoretext',
		'std' => 'Read More',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for footer latest posts', 'organizing-pro'),
		'id' => 'footerpostslength',
		'std' => '5',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Change read more button text for latest blog post shortcode section', 'organizing-pro'),
		'id' => 'readmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Change Show All Button text for photo gallery section', 'organizing-pro'),
		'id' => 'galleryshowallbtn',
		'std' => 'All',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Change menu word on responsive view', 'organizing-pro'),
		'id' => 'menuwordchange',
		'std' => 'Menu',
		'type' => 'text');			
		
	$options[] = array(
		'name' => __('Blog Single Layout', 'organizing-pro'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'organizing-pro'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );	
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'organizing-pro'),
		'desc' => __('Select layout. eg:right-sidebar, left-sidebar, full-width', 'organizing-pro'),
		'id' => 'woocommercelayout',
		'type' => 'select',
		'std' => 'woocommercesitefull',
		'options' => array('woocommerceright'=>'Woocommerce Right Sidebar', 'woocommerceleft'=>'Woocommerce Left Sidebar', 'woocommercesitefull'=>'Woocommerce Full Width') );	

	$options[] = array(			
		'desc' => __('Select shop page Background color', 'organizing-pro'),
		'id' => 'shopproductbg',
		'std' => '#f7f6f6',
		'type' => 'color');	
	
		
		
	$options[] = array(	
		'name' => __('Testimonials Rotating Speed', 'organizing-pro'),	
		'desc' => __('manage testimonials rotating speed.', 'organizing-pro'),
		'id' => 'testimonialsrotatingspeed',
		'std' => '8000',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('True/False Auto play Testimonials.','organizing-pro'),
		'id' => 'testimonialsautoplay',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'True', 'false'=>'False'));			
		

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'organizing-pro'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Number of Sections', 'organizing-pro'),
		'desc' => __('Select number of sections', 'organizing-pro'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '10',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 10 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'organizing-pro'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'organizing-pro'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'organizing-pro'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.', 'organizing-pro'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'organizing-pro'),
			'desc' => __('Select background color for section', 'organizing-pro'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'organizing-pro'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'organizing-pro'),
			'desc' => __('Set class for this section.', 'organizing-pro'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'organizing-pro'),
			'desc'	=> __('Check to hide this section', 'organizing-pro'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'organizing-pro'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'organizing-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'organizing-pro'),
		'desc' => __('Upload inner page banner for site', 'organizing-pro'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/inner-banner.jpg",
		'type' => 'upload');
		
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'organizing-pro'),
		'desc' => __('Enter here your slider shortcode without php tag', 'organizing-pro'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'organizing-pro'),
		'desc' => __('Select slider effect.','organizing-pro'),
		'id' => 'slideefect',
		'std' => 'random',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'organizing-pro'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'organizing-pro'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'organizing-pro'),
		'desc' => __('Hide/Show Direction Naviagtion of slider.','organizing-pro'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','organizing-pro'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','organizing-pro'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));	
		
	$options[] = array(
		'name' => __('Slider Image 1', 'organizing-pro'),
		'desc' => __('First Slide', 'organizing-pro'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'organizing-pro'),
		'id' => 'slidetitle1',
		'std' => 'Onepage WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc1',
		'std' => 'This is an example page. Its different from a blog post because it will stay in one place and will show up in your site navigation.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton1',
		'std' => 'READ MORE',
		'type' => 'text');	

	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl1',
		'std' => '#',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'organizing-pro'),
		'desc' => __('Second Slide', 'organizing-pro'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'organizing-pro'),
		'id' => 'slidetitle2',
		'std' => 'Personal WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc2',
		'std' => 'This is an example page. Its different from a blog post because it will stay in one place and will show up in your site navigation (in most themes). Most people start with an About page that introduces them to potential site visitors.',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton2',
		'std' => 'READ MORE',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl2',
		'std' => '#',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 3', 'organizing-pro'),
		'desc' => __('Third Slide', 'organizing-pro'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'organizing-pro'),
		'id' => 'slidetitle3',
		'std' => 'Flexible WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc3',
		'std' => 'Duis rutrum tincidunt turpis, sit amet pharetra dui sodales ac. Vestibulum porta ligula at quam suscipit pharetra about page that introduces them to potential site visitors..',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton3',
		'std' => 'READ MORE',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl3',
		'std' => '#',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 4', 'organizing-pro'),
		'desc' => __('Third Slide', 'organizing-pro'),
		'id' => 'slide4',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'organizing-pro'),
		'id' => 'slidetitle4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'organizing-pro'),
		'desc' => __('Fifth Slide', 'organizing-pro'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'organizing-pro'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'organizing-pro'),
		'desc' => __('Sixth Slide', 'organizing-pro'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 6', 'organizing-pro'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'organizing-pro'),
		'desc' => __('Seventh Slide', 'organizing-pro'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'organizing-pro'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'organizing-pro'),
		'desc' => __('Eighth Slide', 'organizing-pro'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'organizing-pro'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'organizing-pro'),
		'desc' => __('Ninth Slide', 'organizing-pro'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'organizing-pro'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'organizing-pro'),
		'desc' => __('Tenth Slide', 'organizing-pro'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'organizing-pro'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'organizing-pro'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'organizing-pro'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'organizing-pro'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');
	

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'organizing-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'organizing-pro'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'organizing-pro'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'threecolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );			

	$options[] = array(
		'name' => __('Footer Navigation', 'organizing-pro'),
		'desc' => __('Navigation text title for footer', 'organizing-pro'),
		'id' => 'navigation',
		'std' => 'Navigation',
		'type' => 'text');
		

	$options[] = array(
		'name' => __('Latest Posts Title', 'organizing-pro'),
		'desc' => __('Footer latest posts title.', 'organizing-pro'),
		'id' => 'letestpoststitle',
		'std' => 'Recent News',
		'type' => 'text');			
		
	$options[] = array(
		'name' => __('Footer Menu Title', 'organizing-pro'),
		'desc' => __('footer menu title.', 'organizing-pro'),
		'id' => 'footermenutitle',
		'std' => 'Main Navigation',
		'type' => 'text');			
		
	$options[] = array(
		'name' => __('Footer Contact Info', 'organizing-pro'),
		'desc' => __('Add footer contact info ', 'organizing-pro'),
		'id' => 'contacttitle',
		'std' => 'Contact Info',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address here.', 'organizing-pro'),
		'id' => 'address',
		'std' => '109 kanama Street, Lorem Isput  oly New York- United State',
		'type' => 'textarea');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'organizing-pro'),
		'id' => 'phone',
		'std' => '+91 987 654 3210',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add fax number here.', 'organizing-pro'),
		'id' => 'fax',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Add email address here.', 'organizing-pro'),
		'id' => 'email',
		'std' => 'info@sitename.com',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Footer Social Icons', 'organizing-pro'),
		'desc' => __('social icons for footer', 'organizing-pro'),
		'id' => 'footersocialicon',
		'std' => '[social_area]
[social icon="fab fa-facebook-f" link="#"] 
[social icon="fab fa-twitter" link="#"] 
[social icon="fab fa-linkedin-in" link="#"] 
[social icon="fab fa-google-plus-g" link="#"] 
[/social_area]',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Copyright', 'organizing-pro'),
		'desc' => __('Copyright Text for your site.', 'organizing-pro'),
		'id' => 'copytext',
		'std' => ' Copyright &copy; 2020. All rights reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'organizing-pro'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('https://gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footer Back to Top Button', 'organizing-pro'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'organizing-pro'),
		'type' => 'heading');
	
	$options[] = array(
		'name' => __('Services Slider Below', 'organizing-pro'),
		'desc' => __('[servicesbox image="ADD YOUR IMAGE URL HERE" title="FREE SHIPPING" description="Free shipping on all USA order"][servicesbox image="ADD YOUR IMAGE URL HERE" title="ONLINE SUPPORT" description="We support online 24/7 on day"][servicesbox image="ADD YOUR IMAGE URL HERE" title="MONEY BACK GUARENTEE" description="30 days money back guarentee"][servicesbox image="ADD YOUR IMAGE URL HERE" title="SAFE PAYMENT" description="Protect online payment"][clear]
			', 'organizing-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Photo Gallery', 'organizing-pro'),
		'desc' => __('[photogallery filter="true" show="8"]', 'organizing-pro'),
		'type' => 'info');	
		 		
	$options[] = array(
		'name' => __('Testimonials Rotator', 'organizing-pro'),
		'desc' => __('[testimonials]', 'organizing-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('All Testimonials Listing', 'organizing-pro'),
		'desc' => __('[testimonials-listing show="10"]', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Sidebar Testimonials Rotator', 'organizing-pro'),
		'desc' => __('[sidebar-testimonials]', 'organizing-pro'),
		'type' => 'info');		
		
	$options[] = array(
		'name' => __('Client Rotator', 'organizing-pro'),
		'desc' => __('[client_lists]<br />
		[client title="Enter here title" image="Enter here client image logo url with https:" link="#"]<br />
		[client title="Enter here title" image="Enter here client image logo url with https:" link="#"]<br />
		[client title="Enter here title" image="Enter here client image logo url with https:" link="#"]<br />
		[client title="Enter here title" image="Enter here client image logo url with https:" link="#"]<br />
		[client title="Enter here title" image="Enter here client image logo url with https:" link="#"]<br />
		[/client_lists]', 'organizing-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Contact Form', 'organizing-pro'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'organizing-pro'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Our Team', 'organizing-pro'),
		'desc' => __('[our-team show="4" teammemberlength="25"]', 'organizing-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Latest News', 'organizing-pro'),
		'desc' => __('[latestposts show="3" catid=""]', 'organizing-pro'),
		'type' => 'info');
		
		
	$options[] = array(
		'name' => __('Feature Services', 'organizing-pro'),
		'desc' => __('[servicesbox color="#ffffff" bgcolor="#1e9d74" image="http://www.yoururl.com/images/services-icon-1.png" title="6499 M" description="ALTITUDE HIKED"][servicesbox color="#ffffff" bgcolor="#169069" image="http://www.yoururl.com/images/services-icon-2.png" title="299 KM" description="DISTANCE COVERED"][servicesbox color="#ffffff" bgcolor="#128460" image="http://www.yoururl.com/images/services-icon-3.png" title="110 KG" description="CARBON OFFSET"][servicesbox color="#ffffff" bgcolor="#0b7956" image="http://www.yoururl.com/images/services-icon-4.png" title="707 DAYS" description="SPENT TREKKING"]', 'organizing-pro'),
		'type' => 'info');
		

	$options[] = array(
		'name' => __('Our Skills', 'organizing-pro'),
		'desc' => __('[skill title="Coding" percent="90" bgcolor="#65676a"][skill title="Design" percent="70" bgcolor="#65676a"][skill title="Building" percent="55" bgcolor="#65676a"][skill title="SEO" percent="100" bgcolor="#65676a"]', 'organizing-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Custom Button', 'organizing-pro'),
		'desc' => __('[button align="center" name="View Gallery" link="#" target=""]', 'organizing-pro'),
		'type' => 'info');			
			
		$options[] = array(
		'name' => __('Our Counter', 'organizing-pro'),
		'desc' => __('[counter iconname="user" value="4599" title="Fashion"][counter iconname="user" value="4599" title="Wedding"][counter iconname="cog" value="999" title="Industrial"][counter iconname="picture-o" value="560" title="Sessions"]', 'organizing-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Search Form', 'organizing-pro'),
		'desc' => __('[searchform]', 'organizing-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: https://fontawesome.com/icons/)', 'organizing-pro'),
		'desc' => __('[social_area]<br />
			[social icon="fab fa-facebook-f" link="#"]<br />
			[social icon="fab fa-twitter" link="#"]<br />
			[social icon="fab fa-google-plus-g" link="#"]<br />
			[social icon="fab fa-linkedin-in" link="#"]<br />
		[/social_area]', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('2 Column Content', 'organizing-pro'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'organizing-pro'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'organizing-pro'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'organizing-pro'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Tabs', 'organizing-pro'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'organizing-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'organizing-pro'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'organizing-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'organizing-pro'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'organizing-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Clear', 'organizing-pro'),
		'desc' => __('<pre>
[clear]
</pre>', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'organizing-pro'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'organizing-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Subtitle', 'organizing-pro'),
		'desc' => __('[subtitle color="#111111" size="15px" margin="0 0 50px 0" description="short descriptio here"]', 'organizing-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Read More Button', 'organizing-pro'),
		'desc' => __('[button align="center" name="READ MORE" link="#" target=""]', 'organizing-pro'),
		'type' => 'info');	
	
	$options[] = array(
		'name' => __('Scroll to Top', 'organizing-pro'),
		'desc' => __('[back-to-top] 
', 'organizing-pro'),
		'type' => 'info');

	return $options;
}