<?php
/**
 * Grace Powerclub functions and definitions
 *
 * @package Grace Powerclub
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
function content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('the_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}


if ( ! function_exists( 'powerclub_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function powerclub_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */

	load_theme_textdomain( 'powerclub', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_theme_support( 'title-tag' );
	add_image_size('homepage-thumb',240,145,true);	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'powerclub' ),
		'footer' => __( 'Footer Menu', 'powerclub' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'ffffff'
	) );
	add_editor_style( 'editor-style.css' );
}
endif; // powerclub_setup
add_action( 'after_setup_theme', 'powerclub_setup' );

function powerclub_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'powerclub' ),
		'description'   => __( 'Appears on blog page sidebar', 'powerclub' ),
		'id'            => 'sidebar-1',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '<div class="clear"></div></aside>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'powerclub' ),
		'description'   => __( 'Appears on page sidebar', 'powerclub' ),
		'id'            => 'sidebar-main',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );	
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'powerclub' ),
		'description'   => __( 'Appears on footer', 'powerclub' ),
		'id'            => 'footer-1',
		'before_widget' => '<div id="%1$s" class="widget-column-1">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'powerclub' ),
		'description'   => __( 'Appears on footer', 'powerclub' ),
		'id'            => 'footer-2',
		'before_widget' => '<div id="%1$s" class="widget-column-2">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'powerclub' ),
		'description'   => __( 'Appears on footer', 'powerclub' ),
		'id'            => 'footer-3',
		'before_widget' => '<div id="%1$s" class="widget-column-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'powerclub' ),
		'description'   => __( 'Appears on footer', 'powerclub' ),
		'id'            => 'footer-4',
		'before_widget' => '<div id="%1$s" class="widget-column-4">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5>',
		'after_title'   => '</h5>',
	) );
	
	
	register_sidebar( array(
		'name'          => __( 'Sidebar Contact Page', 'powerclub' ),
		'description'   => __( 'Appears on contact page', 'powerclub' ),
		'id'            => 'sidebar-contact',
		'before_widget' => '<aside class="widget-contact %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Header Widget', 'powerclub' ),
		'description'   => __( 'Appears on header', 'powerclub' ),
		'id'            => 'header-widget',
		'before_widget' => '<div class="headerinfo">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 style="display:none">',
		'after_title'   => '</h6>',
	) );
		

}
add_action( 'widgets_init', 'powerclub_widgets_init' );

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once get_template_directory() . '/inc/options-framework.php';

function powerclub_scripts() {	
	wp_enqueue_style( 'powerclub-gfonts-robotocondensed', '//fonts.googleapis.com/css?family=Roboto+Condensed:400,300,300italic,400italic,700,700italic' );
	wp_enqueue_style( 'powerclub-gfonts-roboto', '//fonts.googleapis.com/css?family=Roboto:400,100,100italic,300,300italic,400italic,500,500italic,700,700italic,900italic' );	
	wp_enqueue_style( 'powerclub-gfonts-oswald', '//fonts.googleapis.com/css?family=Oswald:400,300,700' );
	wp_enqueue_style( 'powerclub-gfonts-opensans', '//fonts.googleapis.com/css?family=Open+Sans:400,300,300italic,400italic,600italic,600,700,700italic,800italic,800' );	
	

	if( of_get_option('bodyfontface',true) != '' ){
		wp_enqueue_style( 'powerclub-gfonts-body', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('bodyfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if( of_get_option('logofontface',true) != '' ){
		wp_enqueue_style( 'powerclub-gfonts-logo', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('logofontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('navfontface', true) != '' ) {
		wp_enqueue_style( 'powerclub-gfonts-nav', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('navfontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}
	if ( of_get_option('headfontface', true) != '' ) {
		wp_enqueue_style( 'powerclub-gfonts-heading', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('headfontface',true)) .'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin');
	}
 	if ( of_get_option('oswaldfontface', true) != '' ) {
		wp_enqueue_style( 'powerclub-gfonts-teamserv', '//fonts.googleapis.com/css?family='.rawurlencode(of_get_option('oswaldfontface',true)).'&subset=cyrillic,arabic,bengali,cyrillic,cyrillic-ext,devanagari,greek,greek-ext,gujarati,hebrew,latin-ext,tamil,telugu,thai,vietnamese,latin' );
	}

	wp_enqueue_style( 'powerclub-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'powerclub-editor-style', get_template_directory_uri().'/editor-style.css' );
	wp_enqueue_style( 'powerclub-base-style', get_template_directory_uri().'/css/default.css' );	
	if ( is_home() || is_front_page() ) { 
	wp_enqueue_style( 'powerclub-nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
	wp_enqueue_script( 'powerclub-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}	
	
	wp_enqueue_script( 'powerclub-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	wp_enqueue_style( 'powerclub-font-awesome-style', get_template_directory_uri().'/css/font-awesome.css' );
	wp_enqueue_style( 'powerclub-animation', get_template_directory_uri().'/css/animation.css' );
	wp_enqueue_style( 'powerclub-hover', get_template_directory_uri().'/css/hover.css' );
	wp_enqueue_style( 'powerclub-hover-min', get_template_directory_uri().'/css/hover-min.css' );
	wp_enqueue_script( 'powerclub-testimonialsminjs', get_template_directory_uri().'/testimonialsrotator/js/jquery.quovolver.min.js', array('jquery') );	
	wp_enqueue_style( 'powerclub-testimonialslider-style', get_template_directory_uri().'/testimonialsrotator/js/tm-rotator.css' );	
	wp_enqueue_style( 'powerclub-responsive-style', get_template_directory_uri().'/css/responsive.css' );		
	wp_enqueue_style( 'powerclub-owl-style', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.css' );
	wp_enqueue_script( 'powerclub-owljs', get_template_directory_uri().'/testimonialsrotator/js/owl.carousel.js', array('jquery') );	
	
	wp_enqueue_script( 'powerclub-counterup', get_template_directory_uri().'/counter/js/jquery.counterup.min.js', array('jquery') );
	wp_enqueue_script( 'powerclub-waypoints', get_template_directory_uri().'/counter/js/waypoints.min.js', array('jquery') );
	
	
	// mixitup script
	wp_enqueue_style( 'powerclub-mixitup-style', get_template_directory_uri().'/mixitup/style-mixitup.css' );
	wp_enqueue_script( 'powerclub-jquery_013-script', get_template_directory_uri() . '/mixitup/jquery_013.js', array('jquery') );
	wp_enqueue_script( 'powerclub-jquery_003-script', get_template_directory_uri() . '/mixitup/jquery_003.js', array('jquery') );
	wp_enqueue_script( 'powerclub-screen-script', get_template_directory_uri() . '/mixitup/screen.js', array('jquery') );
	// prettyPhoto script
	wp_enqueue_style( 'powerclub-prettyphoto-style', get_template_directory_uri().'/mixitup/prettyPhotoe735.css' );
	wp_enqueue_script( 'powerclub-prettyphoto-script', get_template_directory_uri() . '/mixitup/jquery.prettyPhoto5152.js', array('jquery') );	
	
	
	// mixitup gallery	
	wp_enqueue_script( 'powerclub-mixitup-scripts', get_template_directory_uri().'/mixitup/jquery_mixitup.js' );
	
	if( of_get_option('scrollanimation',true) != true) {
		wp_enqueue_style( 'powerclub-animation-style', get_template_directory_uri().'/css/animation-style.css' );
		wp_enqueue_script( 'powerclub-custom-animation', get_template_directory_uri() . '/js/custom-animation.js', array('jquery') );	
	}
	
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'powerclub_scripts' );

function media_css_hook(){
	
	?>
    	
    	<script>			
		jQuery(window).load(function() {
        jQuery('#slider').nivoSlider({
        	effect:'<?php echo of_get_option('slideefect',true); ?>', //sliceDown, sliceDownLeft, sliceUp, sliceUpLeft, sliceUpDown, sliceUpDownLeft, fold, fade, random, slideInRight, slideInLeft, boxRandom, boxRain, boxRainReverse, boxRainGrow, boxRainGrowReverse
		  	animSpeed: <?php echo of_get_option('slideanim',true); ?>,
			pauseTime: <?php echo of_get_option('slidepause',true); ?>,
			directionNav: <?php echo of_get_option('slidenav',true); ?>,
			controlNav: <?php echo of_get_option('slidepage',true); ?>,
			pauseOnHover: <?php echo of_get_option('slidepausehover',true); ?>,
    });
});

jQuery(window).load(function() {   
  jQuery('.owl-carousel').owlCarousel({
    loop:true,	
	autoplay: <?php echo of_get_option('testimonialsautoplay',true); ?>,
	autoplayTimeout: <?php echo of_get_option('testimonialsrotatingspeed',true); ?>,
    margin:40,
    nav:true,
	dots: false,
    responsive:{
        0:{
            items:1
        },
        600:{
            items:1
        },
        1000:{
            items:1
        }
    }
})
    
  });


jQuery(window).bind('scroll', function() {
	var wwd = jQuery(window).width();
	if( wwd > 999 ){
		var navHeight = jQuery( window ).height() - 565;
		<?php if( of_get_option('headstick',true) != true) { ?>
		if (jQuery(window).scrollTop() > navHeight) {
			jQuery('.header').addClass('fixed');
		}else {
			jQuery('.header').removeClass('fixed');
		}
		<?php } ?>
	}
});


jQuery(document).ready(function() {
  
  jQuery('.link').on('click', function(event){
    var $this = jQuery(this);
    if($this.hasClass('clicked')){
      $this.removeAttr('style').removeClass('clicked');
    } else{
      $this.css('background','#7fc242').addClass('clicked');
    }
  });
 
});
		</script>
<?php 
}
add_action('wp_head','media_css_hook'); 


function powerclub_custom_head_codes() { 
	if ( function_exists('of_get_option') ){
		if ( of_get_option('style2', true) != '' ) {
			echo "<style>". esc_html( of_get_option('style2', true) ) ."</style>";
		}
		echo "<style>";
		if ( of_get_option('bodyfontface', true) != '') {
			echo 'body{font-family:\''. esc_html( of_get_option('bodyfontface', true) ) .'\', sans-serif;}';
		}
		if ( of_get_option('bodyfontcolor', true) != '' ) {
			echo 'body, .contact-form-section .address,  .accordion-box .acc-content{color:'. esc_html( of_get_option('bodyfontcolor', true) ) .';}';
		}
		if( of_get_option('bodyfontsize',true) != ''){
			echo "body{font-size:".of_get_option('bodyfontsize',true)."}";
		}
		if( of_get_option('logofontface',true) != '' || of_get_option('logofontcolor',true) != '' || of_get_option('logofontsize',true) != ''){
			echo ".logo h1 {font-family:".of_get_option('logofontface').";color:".of_get_option('logofontcolor',true).";font-size:".of_get_option('logofontsize',true)."}";
		}
		if( of_get_option('logotaglinecolor',true) != '' ){
			echo ".tagline{color:".of_get_option('logotaglinecolor',true).";}";
		}
		if( of_get_option('logoheight',true) != '' ){
			echo ".logo img{height:".of_get_option('logoheight',true).";}";
		}		
				
	
		if ( of_get_option('headerbgcolor', true) != '' ) {
			echo ".sitenav ul li:hover > ul{background-color:".of_get_option('headerbgcolor',true).";}";
		}			
		if( of_get_option('lastwordcolor',true) != '' ){
			echo ".logo h1 span, h2.section_title span, .leftwrap h2 span{color:".of_get_option('lastwordcolor',true).";}";
		}		
		if ( of_get_option('navbdcolor', true) != '') {
			echo ".sitenav{border-color:".of_get_option('navbdcolor', true).";}";
		}
		if ( of_get_option('navlibdcolor', true) != '') {
			echo ".sitenav ul li ul li{border-color:".of_get_option('navlibdcolor', true).";}";
		}
		if ( of_get_option('navfontface', true) != '' || of_get_option('navfontsize',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize',true).'}';
		}
		
		if ( of_get_option('navfontface', true) != '' || of_get_option('navfontsize',true) != '' ) {
			echo '.sitenav ul{font-family:\''. esc_html( of_get_option('navfontface', true) ) .'\', sans-serif;font-size:'.of_get_option('navfontsize',true).'}';
		}
		
		if ( of_get_option('navfontcolor', true) != '' ) {
			echo '.sitenav ul li a{color:'. esc_html( of_get_option('navfontcolor', true) ) .';}';
		}
		
		if ( of_get_option('navhovercolor', true) != '') {
			echo '.sitenav ul li a:hover, .sitenav ul li.current_page_item a, .sitenav ul li.current_page_item ul li a:hover, .sitenav ul li.current-menu-ancestor a.parent{ color:'. esc_html( of_get_option('navhovercolor', true) ) .';}';
		}	
		 
		if( of_get_option('sectitlesize',true) != '' || of_get_option('sectitlecolor',true) != '' || of_get_option('sectiontitleborder',true) != '' ){
			echo "h2.section_title{ font-size:".of_get_option('sectitlesize',true)."; color:".of_get_option('sectitlecolor',true)."; border-color:".of_get_option('sectiontitleborder',true)."}";
		}	
			
		
		if ( of_get_option('linkcolor', true) != '' ) {
			echo 'a, .slide_toggle a, .news-box h6 a:hover{color:'. esc_html( of_get_option('linkcolor', true) ) .';}';
		}
		if ( of_get_option('linkhovercolor', true) != '' ) {
			echo 'a:hover, .slide_toggle a:hover{color:'. esc_html( of_get_option('linkhovercolor', true) ) .';}';
		}			
		if( of_get_option('foottitlecolor', true) != '' || of_get_option('ftfontsize', true) != '' ){
			echo ".footer h5{color:".of_get_option('foottitlecolor', true)."; font-size:".of_get_option('ftfontsize', true)."; }";
		}							
		if( of_get_option('copycolor', true) != ''){
			echo ".copyright-txt{color:".of_get_option('copycolor',true)."}";
		}
		if( of_get_option('designcolor', true) != ''){
			echo ".design-by{color:".of_get_option('designcolor',true)."}";
		}		
		if ( of_get_option('headerbgcolor', true) != '' ) {
			echo ".header{background-color:".of_get_option('headerbgcolor',true)."}";
		}				
		if( of_get_option('socialfontcolor',true) != '' ){
			echo ".social-icons a{ color:".of_get_option('socialfontcolor',true).";}";
		}			
		if( of_get_option('socialfonthvcolor',true) != ''){
			echo ".social-icons a:hover{ color:".of_get_option('socialfonthvcolor',true)."; }";
		}	
				
		if( of_get_option('btnbgcolor',true) != '' || of_get_option('btntxtcolor', true) != ''){
			echo ".button, #commentform input#submit, input.search-submit, .post-password-form input[type=submit], p.read-more a, .accordion-box h2:before, .pagination ul li span, .pagination ul li a, .headertop .right a, .wpcf7 form input[type='submit']{background-color:".of_get_option('btnbgcolor',true)."; color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo ".button:hover, #commentform input#submit:hover, input.search-submit:hover, .post-password-form input[type=submit]:hover, p.read-more a:hover, .pagination ul li .current, .pagination ul li a:hover,.headertop .right a:hover, .wpcf7 form input[type='submit']:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}		
		if( of_get_option('btnbgcolor',true) != '' || of_get_option('btntxtcolor', true) != ''){
			echo "a.morebutton{background-color:".of_get_option('btnbgcolor',true)."; color:". of_get_option('btntxtcolor', true) ."; }";
		}
		if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
			echo "a.morebutton:hover{background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
		}	
		if ( of_get_option('widgetboxborder', true) != '' ) {
		echo "aside.widget{ border-color:".of_get_option('widgetboxborder', true)."; }";
		}			
		if ( of_get_option('wdgttitleccolor', true) != '' || of_get_option('widgettitleborder', true) != '' ) {
			echo "h3.widget-title{ color:".of_get_option('wdgttitleccolor', true)."; border-color:".of_get_option('widgettitleborder', true).";}";
		}				
		if ( of_get_option('footerbgcolor', true) != '' || of_get_option('footdesccolor', true) != '' ) {
		echo "#footer-wrapper{background-color:".of_get_option('footerbgcolor', true)."; color:".of_get_option('footdesccolor', true).";}";
		}		
		if ( of_get_option('footercolumnbdcolor', true) != '') {
			echo ".cols-4 h5, div.recent-post, div.recent-post img{border-color:".of_get_option('footercolumnbdcolor', true).";}";
		}		
		if ( of_get_option('footermenucolor', true) != '' ) {
			echo ".phone-no a:hover, .footer h5 span, .footer ul li a:hover, .footer ul li.current_page_item a, div.recent-post a:hover{color:".of_get_option('footermenucolor', true)."; }";
		}
		if ( of_get_option('footdesccolor', true) != '' ) {
			echo ".phone-no a{color:".of_get_option('footdesccolor', true)."; }";
		}			
		if ( of_get_option('copybgcolor', true) != '' ) {
			echo '.copyright-wrapper{background-color:'. esc_html( of_get_option('copybgcolor', true) ) .';}';
		}		
		
		if( of_get_option('sldpagebg',true) != ''){
			echo ".nivo-controlNav a{background-color:".of_get_option('sldpagebg',true)."}";
		}
		if( of_get_option('sldpagehvbg',true) != ''){
			echo ".nivo-controlNav a.active{background-color:".of_get_option('sldpagehvbg',true)."}";
		}	
		if( of_get_option('sldpagehvbd',true) != ''){
			echo ".nivo-controlNav a{border-color:".of_get_option('sldpagehvbd',true)."}";
		}	
		if( of_get_option('sidebarfontcolor',true) != '' || of_get_option('sidebarliaborder', true) != '' ){
			echo "#sidebar ul li a{color:".of_get_option('sidebarfontcolor',true)."; border-bottom:1px dashed ".of_get_option('sidebarliaborder',true)."}";
		}		
		if( of_get_option('sidebarfonthvcolor',true) != '' ){
			echo "#sidebar ul li a:hover{color:".of_get_option('sidebarfonthvcolor',true)."; }";
		}	
		if ( of_get_option('slidetitlefontface', true) != '' || of_get_option('slidetitlecolor', true) != '' || of_get_option('slidetitlefontsize', true) != '') {
		echo ".slide_info h2{ font-family:".of_get_option('slidetitlefontface', true)."; color:".of_get_option('slidetitlecolor', true)."; font-size:".of_get_option('slidetitlefontsize', true).";}";
		}
		
		if ( of_get_option('slidedesfontface', true) != '' || of_get_option('slidedesccolor', true) != '' || of_get_option('slidedescfontsize', true) != '') {
		echo ".slide_info p{font-family:".of_get_option('slidedesfontface', true)."; color:".of_get_option('slidedesccolor', true)."; font-size:".of_get_option('slidedescfontsize', true).";}";
		}
		if ( of_get_option('copylinks', true) != '' ) {
		echo ".copyright-wrapper a{ color: ".of_get_option('copylinks', true)."; }";
		}	
		if ( of_get_option('copylinkshover', true) != '' ) {
		echo ".copyright-wrapper a:hover{ color: ".of_get_option('copylinkshover', true)."; }";
		}	
		
		if ( of_get_option('togglemenu', true) != '' ) {
		echo ".toggle a{ background-color:".of_get_option('togglemenu', true)."; }";
		}
		
		if ( of_get_option('top4boxeshovercolor', true) != '' ) {
		echo ".four-pagecolumn:hover h3{ color: ".of_get_option('top4boxeshovercolor', true)."; }";
		}
		if ( of_get_option('top4boxeshovercolor', true) != '' ) {
		echo ".four-pagecolumn:hover .pagemore{ background-color: ".of_get_option('top4boxeshovercolor', true)."; }";
		}
		if ( of_get_option('galleryactivebgcolor', true) != '' ) {
		echo "ul.portfoliofilter li a.selected, ul.portfoliofilter li:hover a, ul.portfoliofilter li a:hover{ background-color: ".of_get_option('galleryactivebgcolor', true)."; }";
		}
		if ( of_get_option('pageboxedbgcolor', true) != '' ) {
			echo '.four-pagecolumn .thumbbx{background-color:'. esc_html( of_get_option('pageboxedbgcolor', true) ) .';}';
		}
		if ( of_get_option('yogaservicesbgcolor', true) != '' ) {
			echo '.hvr-rectangle-out::before{background-color:'. esc_html( of_get_option('yogaservicesbgcolor', true) ) .';}';
		}
		if ( of_get_option('teamboxbgcolor', true) != '' ) {
			echo '.teammember-list .thumnailbx{background-color:'. esc_html( of_get_option('teamboxbgcolor', true) ) .';}';
		}
		if ( of_get_option('newsboxbgcolor', true) != '' ) {
			echo '.news-box .news-thumb{background-color:'. esc_html( of_get_option('newsboxbgcolor', true) ) .';}';
		}
		if ( of_get_option('whatweoffertitle', true) != '' ) {
		echo ".servingyou h6{ color: ".of_get_option('whatweoffertitle', true)."; }";
		}
				
		
/* Heading */

		if( of_get_option('headfontface', true) != '' ){
			echo "h1,h2,h3,h4,h5,h6{ font-family:".of_get_option('headfontface',true)."; }";
		}
		
		if ( of_get_option('h1fontsize', true) != '' || of_get_option('h1fontcolor', true) != '' ) {
			echo "h1{ font-size:".of_get_option('h1fontsize', true)."; color:".of_get_option('h1fontcolor', true).";}";
		}

		if ( of_get_option('h2fontsize', true) != '' || of_get_option('h2fontcolor', true) != '' ) {
			echo "h2{ font-size:".of_get_option('h2fontsize', true)."; color:".of_get_option('h2fontcolor', true).";}";
		}		
		
		if ( of_get_option('h3fontsize', true) != '' || of_get_option('h3fontcolor', true) != '' ) {
			echo "h3{ font-size:".of_get_option('h3fontsize', true)."; color:".of_get_option('h3fontcolor', true).";}";
		}	
		
		if ( of_get_option('h4fontsize', true) != '' || of_get_option('h4fontcolor', true) != '' ) {
			echo "h4{ font-size:".of_get_option('h4fontsize', true)."; color:".of_get_option('h4fontcolor', true).";}";
		}	
		
		if ( of_get_option('h5fontsize', true) != '' || of_get_option('h5fontcolor', true) != '' ) {
			echo "h5{font-size:".of_get_option('h5fontsize', true)."; color:".of_get_option('h5fontcolor', true).";}";
		}		
		if ( of_get_option('h6fontsize', true) != '' || of_get_option('h6fontcolor', true) != '' ) {
			echo "h6{ font-size:".of_get_option('h6fontsize', true)."; color:".of_get_option('h6fontcolor', true).";}";
		}
/* Custom editable */
			
		if ( of_get_option('appontmentbtn', true) != '' ) {
			echo ".appointmentbtn{ color:".of_get_option('appontmentbtn', true)."; border-color:".of_get_option('appontmentbtn', true).";}";
		}		
		if ( of_get_option('appontmentbtnhover', true) != '' ) {
			echo ".appointmentbtn:hover{ color:".of_get_option('appontmentbtnhover', true)."; border-color:".of_get_option('appontmentbtnhover', true).";}";
		}
		if ( of_get_option('teambgcolor', true) != '' ) {
			echo ".teammember-content{ background-color:".of_get_option('teambgcolor', true)."; }";
		}		
		if ( of_get_option('lastwordcolor', true) != '' || of_get_option('teamborder', true) != '' ) {
			echo ".teammember-content span{ color:".of_get_option('lastwordcolor', true)."; border-color:".of_get_option('teamborder', true).";}";
		}		
		if ( of_get_option('countercirclecolor', true) != '' ) {
			echo ".counterlist{ color:".of_get_option('countercirclecolor', true).";}";
		}		
		if ( of_get_option('countercirclecolor', true) != '' ) {
			echo ".counterlist h6{ color:".of_get_option('countercirclecolor', true).";}";
		}
		if ( of_get_option('countercirclenumber', true) != '' ) {
			echo ".counterlist .counter{ color:".of_get_option('countercirclenumber', true).";}";
		}
		
		if ( of_get_option('testimonialdesc', true) != '' ) {
			echo ".client-say{ color:".of_get_option('testimonialdesc', true).";}";
		}
		if ( of_get_option('testimonialtitle', true) != '' ) {
			echo ".client-say h6{ color:".of_get_option('testimonialtitle', true).";}";
		}
		
		if ( of_get_option('footsocialcolor', true) != '' ) {
			echo ".footer .social-icons a{ color:".of_get_option('footsocialcolor', true)."; border-color:".of_get_option('footsocialcolor', true).";}";
		}
		
		if ( of_get_option('footsocialhvcolor', true) != '' ) {
			echo ".footer .social-icons a:hover{ color:".of_get_option('footsocialhvcolor', true)."; border-color:".of_get_option('footsocialhvcolor', true).";}";
		}
		
		if ( of_get_option('footerallborder', true) != '' ) {
			echo ".footer h5, .footer ul li a, div.recent-post{ border-color:".of_get_option('footerallborder', true)."; }";
		}
		if ( of_get_option('thirdsectionborder', true) != '' ) {
			echo ".services-title h4::after{ border-color:".of_get_option('thirdsectionborder', true)."; }";
		}
		if ( of_get_option('fitnessofferspan', true) != '' ) {
			echo "#promowraper h3 span{ color:".of_get_option('fitnessofferspan', true)."; }";
		}
		if ( of_get_option('wtweofferunderline', true) != '' ) {
			echo ".servingyou-des{ border-color:".of_get_option('wtweofferunderline', true)."; }";
		}
		
		if ( of_get_option('headertopbgcolor', true) != '' || of_get_option('headertopcolor', true) != '' ) {
			echo ".header-top{ background-color:".of_get_option('headertopbgcolor', true)."; color:".of_get_option('headertopcolor', true).";}";
		}
		
		
		

		echo "</style>";
	}
}
add_action('wp_head', 'powerclub_custom_head_codes');


function powerclub_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';

function excerpt($num) {
        $limit = $num+1;
        $excerpt = explode(' ', get_the_excerpt(), $limit);
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt)."...";
        echo $excerpt;
    }
	
function powerclub_string_limit_words($string, $word_limit){
  $words = explode(' ', $string, ($word_limit + 1));
  if(count($words) > $word_limit)
  array_pop($words);
  return implode(' ', $words);
}	

function powerclub_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}
// get slug by id
function powerclub_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}

/**

 * Include the Plugin_Activation class.

 */

require_once dirname( __FILE__ ) . '/class-plugin-activation.php';
function powerclub_register_required_plugins() {

	$plugins = array(		
		array(
			'name'      => 'Master Slider - Responsive Touch Slider',
			'slug'      => 'master-slider',
			'required'  => false,
		),

	);

	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'grc-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);
	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'powerclub_register_required_plugins' );