<?php 
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'powerclub'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '',
    'ABeeZee' => 'ABeeZee',
    'Abel' => 'Abel',
    'Abril Fatface' => 'Abril Fatface',
    'Aclonica' => 'Aclonica',
    'Acme' => 'Acme',
    'Actor' => 'Actor',
    'Adamina' => 'Adamina',
    'Advent Pro' => 'Advent Pro',
    'Aguafina Script' => 'Aguafina Script',
    'Akronim' => 'Akronim',
    'Aladin' => 'Aladin',
    'Aldrich' => 'Aldrich',
    'Alegreya' => 'Alegreya',
    'Alegreya Sans SC' => 'Alegreya Sans SC',
    'Alegreya SC' => 'Alegreya SC',
    'Alex Brush' => 'Alex Brush',
    'Alef' => 'Alef',
    'Alfa Slab One' => 'Alfa Slab One',
    'Alice' => 'Alice',
    'Alike' => 'Alike',
    'Alike Angular' => 'Alike Angular',
    'Allan' => 'Allan',
    'Allerta' => 'Allerta',
    'Allerta Stencil' => 'Allerta Stencil',
    'Allura' => 'Allura',
    'Almendra' => 'Almendra',
    'Almendra Display' => 'Almendra Display',
    'Almendra SC' => 'Almendra SC',
    'Amiri' => 'Amiri',
    'Amarante' => 'Amarante',
    'Amaranth' => 'Amaranth',
    'Amatic SC' => 'Amatic SC',
    'Amethysta' => 'Amethysta',
    'Amita' => 'Amita',
    'Anaheim' => 'Anaheim',
    'Andada' => 'Andada',
    'Andika' => 'Andika',
    'Annie Use Your Telescope' => 'Annie Use Your Telescope',
    'Anonymous Pro' => 'Anonymous Pro',
    'Antic' => 'Antic',
    'Antic Didone' => 'Antic Didone',
    'Antic Slab' => 'Antic Slab',
    'Anton' => 'Anton',
    'Angkor' => 'Angkor',
    'Arapey' => 'Arapey',
    'Arbutus' => 'Arbutus',
    'Arbutus Slab' => 'Arbutus Slab',
    'Architects Daughter' => 'Architects Daughter',
    'Archivo White' => 'Archivo White',
    'Archivo Narrow' => 'Archivo Narrow',
    'Arial' => 'Arial',
    'Arimo' => 'Arimo',
    'Arya' => 'Arya',
    'Arizonia' => 'Arizonia',
    'Armata' => 'Armata',
    'Artifika' => 'Artifika',
    'Arvo' => 'Arvo',
    'Asar' => 'Asar',
    'Asap' => 'Asap',
    'Asset' => 'Asset',
    'Astloch' => 'Astloch',
    'Asul' => 'Asul',
    'Atomic Age' => 'Atomic Age',
    'Aubrey' => 'Aubrey',
    'Audiowide' => 'Audiowide',
    'Autour One' => 'Autour One',
    'Average' => 'Average',
    'Average Sans' => 'Average Sans',
    'Averia Gruesa Libre' => 'Averia Gruesa Libre',
    'Averia Libre' => 'Averia Libre',
    'Averia Sans Libre' => 'Averia Sans Libre',
    'Averia Serif Libre' => 'Averia Serif Libre',
    'Battambang' => 'Battambang',
    'Bad Script' => 'Bad Script',
    'Bayon' => 'Bayon',
    'Balthazar' => 'Balthazar',
    'Bangers' => 'Bangers',
    'Basic' => 'Basic',
    'Baumans' => 'Baumans',
    'Belgrano' => 'Belgrano',
    'Belleza' => 'Belleza',
    'BenchNine' => 'BenchNine',
    'Bentham' => 'Bentham',
    'Berkshire Swash' => 'Berkshire Swash',
    'Bevan' => 'Bevan',
    'Bigelow Rules' => 'Bigelow Rules',
    'Bigshot One' => 'Bigshot One',
    'Bilbo' => 'Bilbo',
    'Bilbo Swash Caps' => 'Bilbo Swash Caps',
    'Biryani' => 'Biryani',
    'Bitter' => 'Bitter',
    'White Ops One' => 'White Ops One',
    'Bokor' => 'Bokor',
    'Bonbon' => 'Bonbon',
    'Boogaloo' => 'Boogaloo',
    'Bowlby One' => 'Bowlby One',
    'Bowlby One SC' => 'Bowlby One SC',
    'Brawler' => 'Brawler',
    'Bree Serif' => 'Bree Serif',
    'Bubblegum Sans' => 'Bubblegum Sans',
    'Bubbler One' => 'Bubbler One',
    'Buda' => 'Buda',
    'Buenard' => 'Buenard',
    'Butcherman' => 'Butcherman',
    'Butcherman Caps' => 'Butcherman Caps',
    'Butterfly Kids' => 'Butterfly Kids',
    'Cabin' => 'Cabin',
    'Cabin Condensed' => 'Cabin Condensed',
    'Cabin Sketch' => 'Cabin Sketch',
    'Cabin' => 'Cabin',
    'Caesar Dressing' => 'Caesar Dressing',
    'Cagliostro' => 'Cagliostro',
    'Calligraffitti' => 'Calligraffitti',
    'Cambay' => 'Cambay',
    'Cambo' => 'Cambo',
    'Candal' => 'Candal',
    'Cantarell' => 'Cantarell',
    'Cantata One' => 'Cantata One',
    'Cantora One' => 'Cantora One',
    'Capriola' => 'Capriola',
    'Cardo' => 'Cardo',
    'Carme' => 'Carme',
    'Carrois Gothic' => 'Carrois Gothic',
    'Carrois Gothic SC' => 'Carrois Gothic SC',
    'Carter One' => 'Carter One',
    'Caveat' => 'Caveat',
    'Caveat Brush' => 'Caveat Brush',
    'Catamaran' => 'Catamaran',
    'Caudex' => 'Caudex',
    'Cedarville Cursive' => 'Cedarville Cursive',
    'Ceviche One' => 'Ceviche One',
    'Changa One' => 'Changa One',
    'Chango' => 'Chango',
    'Chau Philomene One' => 'Chau Philomene One',
    'Chenla' => 'Chenla',
    'Chela One' => 'Chela One',
    'Chelsea Market' => 'Chelsea Market',
    'Cherry Cream Soda' => 'Cherry Cream Soda',
    'Cherry Swash' => 'Cherry Swash',
    'Chewy' => 'Chewy',
    'Chicle' => 'Chicle',
    'Chivo' => 'Chivo',
    'Chonburi' => 'Chonburi',
    'Cinzel' => 'Cinzel',
    'Cinzel Decorative' => 'Cinzel Decorative',
    'Clicker Script' => 'Clicker Script',
    'Coda' => 'Coda',
    'Codystar' => 'Codystar',
    'Combo' => 'Combo',
    'Comfortaa' => 'Comfortaa',
    'Coming Soon' => 'Coming Soon',
    'Condiment' => 'Condiment',
    'Content' => 'Content',
    'Contrail One' => 'Contrail One',
    'Convergence' => 'Convergence',
    'Cookie' => 'Cookie',
    'Comic Sans MS' => 'Comic Sans MS',
    'Copse' => 'Copse',
    'Corben' => 'Corben',
    'Courgette' => 'Courgette',
    'Cousine' => 'Cousine',
    'Coustard' => 'Coustard',
    'Covered By Your Grace' => 'Covered By Your Grace',
    'Crafty Girls' => 'Crafty Girls',
    'Creepster' => 'Creepster',
    'Creepster Caps' => 'Creepster Caps',
    'Crete Round' => 'Crete Round',
    'Crimson' => 'Crimson',
    'Croissant One' => 'Croissant One',
    'Crushed' => 'Crushed',
    'Cuprum' => 'Cuprum',
    'Cutive' => 'Cutive',
    'Cutive Mono' => 'Cutive Mono',
    'Damion' => 'Damion',
    'Dangrek' => 'Dangrek',
    'Dancing Script' => 'Dancing Script',
    'Dawning of a New Day' => 'Dawning of a New Day',
    'Days One' => 'Days One',
    'Dekko' => 'Dekko',
    'Delius' => 'Delius',
    'Delius Swash Caps' => 'Delius Swash Caps',
    'Delius Unicase' => 'Delius Unicase',
    'Della Respira' => 'Della Respira',
    'Denk One' => 'Denk One',
    'Devonshire' => 'Devonshire',
    'Dhurjati' => 'Dhurjati',
    'Didact Gothic' => 'Didact Gothic',
    'Diplomata' => 'Diplomata',
    'Diplomata SC' => 'Diplomata SC',
    'Domine' => 'Domine',
    'Donegal One' => 'Donegal One',
    'Doppio One' => 'Doppio One',
    'Dorsa' => 'Dorsa',
    'Dosis' => 'Dosis',
    'Dr Sugiyama' => 'Dr Sugiyama',
    'Droid Sans' => 'Droid Sans',
    'Droid Sans Mono' => 'Droid Sans Mono',
    'Droid Serif' => 'Droid Serif',
    'Duru Sans' => 'Duru Sans',
    'Dynalight' => 'Dynalight',
    'EB Garamond' => 'EB Garamond',
    'Eczar' => 'Eczar',
    'Eagle Lake' => 'Eagle Lake',
    'Eater' => 'Eater',
    'Eater Caps' => 'Eater Caps',
    'Economica' => 'Economica',
    'Ek Mukta' => 'Ek Mukta',
    'Electrolize' => 'Electrolize',
    'Elsie' => 'Elsie',
    'Elsie Swash Caps' => 'Elsie Swash Caps',
    'Emblema One' => 'Emblema One',
    'Emilys Candy' => 'Emilys Candy',
    'Engagement' => 'Engagement',
    'Englebert' => 'Englebert',
    'Enriqueta' => 'Enriqueta',
    'Erica One' => 'Erica One',
    'Esteban' => 'Esteban',
    'Euphoria Script' => 'Euphoria Script',
    'Ewert' => 'Ewert',
    'Exo' => 'Exo',
    'Exo 2' => 'Exo 2',
    'Expletus Sans' => 'Expletus Sans',
    'Fanwood Text' => 'Fanwood Text',
    'Fascinate' => 'Fascinate',
    'Fascinate Inline' => 'Fascinate Inline',
    'Fasthand' => 'Fasthand',
    'Faster One' => 'Faster One',
    'Federant' => 'Federant',
    'Federo' => 'Federo',
    'Felipa' => 'Felipa',
    'Fenix' => 'Fenix',
    'Finger Paint' => 'Finger Paint',
    'Fira Mono' => 'Fira Mono',
    'Fira Sans' => 'Fira Sans',
    'Fjalla One' => 'Fjalla One',
    'Fjord One' => 'Fjord One',
    'Flamenco' => 'Flamenco',
    'Flavors' => 'Flavors',
    'Fondamento' => 'Fondamento',
    'Fontdiner Swanky' => 'Fontdiner Swanky',
    'Forum' => 'Forum',
    'Francois One' => 'Francois One',
    'FreeSans' => 'FreeSans',

    'Freckle Face' => 'Freckle Face',
    'Fredericka the Great' => 'Fredericka the Great',
    'Fredoka One' => 'Fredoka One',
    'Fresca' => 'Fresca',
    'Freehand' => 'Freehand',
    'Frijole' => 'Frijole',
    'Fruktur' => 'Fruktur',
    'Fugaz One' => 'Fugaz One',
    'Gafata' => 'Gafata',
    'Galdeano' => 'Galdeano',
    'Galindo' => 'Galindo',
    'Gentium Basic' => 'Gentium Basic',
    'Gentium Book Basic' => 'Gentium Book Basic',
    'Geo' => 'Geo',
    'Georgia' => 'Georgia',
    'Geostar' => 'Geostar',
    'Geostar Fill' => 'Geostar Fill',
    'Germania One' => 'Germania One',
    'Gilda Display' => 'Gilda Display',
    'Give You Glory' => 'Give You Glory',
    'Glass Antiqua' => 'Glass Antiqua',
    'Glegoo' => 'Glegoo',
    'Gloria Hallelujah' => 'Gloria Hallelujah',
    'Goblin One' => 'Goblin One',
    'Gochi Hand' => 'Gochi Hand',
    'Gorditas' => 'Gorditas',
    'Gurajada' => 'Gurajada',
    'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
    'Graduate' => 'Graduate',
    'Grand Hotel' => 'Grand Hotel',
    'Gravitas One' => 'Gravitas One',
    'Great Vibes' => 'Great Vibes',
    'Griffy' => 'Griffy',
    'Gruppo' => 'Gruppo',
    'Gudea' => 'Gudea',
    'Gidugu' => 'Gidugu',
    'GFS Didot' => 'GFS Didot',
    'GFS Neohellenic' => 'GFS Neohellenic',
    'Habibi' => 'Habibi',
    'Hammersmith One' => 'Hammersmith One',
    'Halant' => 'Halant',
    'Hanalei' => 'Hanalei',
    'Hanalei Fill' => 'Hanalei Fill',
    'Handlee' => 'Handlee',
    'Hanuman' => 'Hanuman',
    'Happy Monkey' => 'Happy Monkey',
    'Headland One' => 'Headland One',
    'Henny Penny' => 'Henny Penny',
    'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
    'Hind' => 'Hind',
    'Hind Siliguri' => 'Hind Siliguri',
    'Hind Vadodara' => 'Hind Vadodara',
    'Holtwood One SC' => 'Holtwood One SC',
    'Homemade Apple' => 'Homemade Apple',
    'Homenaje' => 'Homenaje',
    'IM Fell' => 'IM Fell',
    'Itim' => 'Itim',
    'Iceberg' => 'Iceberg',
    'Iceland' => 'Iceland',
    'Imprima' => 'Imprima',
    'Inconsolata' => 'Inconsolata',
    'Inder' => 'Inder',
    'Indie Flower' => 'Indie Flower',
    'Inknut Antiqua' => 'Inknut Antiqua',
    'Inika' => 'Inika',
    'Irish Growler' => 'Irish Growler',
    'Istok Web' => 'Istok Web',
    'Italiana' => 'Italiana',
    'Italianno' => 'Italianno',
    'Jacques Francois' => 'Jacques Francois',
    'Jacques Francois Shadow' => 'Jacques Francois Shadow',
    'Jim Nightshade' => 'Jim Nightshade',
    'Jockey One' => 'Jockey One',
    'Jaldi' => 'Jaldi',
    'Jolly Lodger' => 'Jolly Lodger',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Slab' => 'Josefin Slab',
    'Joti One' => 'Joti One',
    'Judson' => 'Judson',
    'Julee' => 'Julee',
    'Julius Sans One' => 'Julius Sans One',
    'Junge' => 'Junge',
    'Jura' => 'Jura',
    'Just Another Hand' => 'Just Another Hand',
    'Just Me Again Down Here' => 'Just Me Again Down Here',
    'Kadwa' => 'Kadwa',
    'Kdam Thmor' => 'Kdam Thmor',
    'Kalam' => 'Kalam', 
    'Kameron' => 'Kameron',
    'Kantumruy' => 'Kantumruy',
    'Karma' => 'Karma',
    'Karla' => 'Karla',
    'Kaushan Script' => 'Kaushan Script',
    'Kavoon' => 'Kavoon',
    'Keania One' => 'Keania One',
    'Kelly Slab' => 'Kelly Slab',
    'Kenia' => 'Kenia',
    'Khand' => 'Khand',
    'Khmer' => 'Khmer',
    'Khula' => 'Khula',
    'Kite One' => 'Kite One',
    'Knewave' => 'Knewave',
    'Kotta One' => 'Kotta One',
    'Kranky' => 'Kranky',
    'Kreon' => 'Kreon',
    'Kristi' => 'Kristi',
    'Koulen' => 'Koulen',
    'Krona One' => 'Krona One',
    'Kurale' => 'Kurale',
    'Lakki Reddy' => 'Lakki Reddy',
    'La Belle Aurore' => 'La Belle Aurore',
    'Lancelot' => 'Lancelot',
    'Laila' => 'Laila',
    'Lato' => 'Lato',
    'Lateef' => 'Lateef',
    'League Script' => 'League Script',
    'Leckerli One' => 'Leckerli One',
    'Ledger' => 'Ledger',
    'Lekton' => 'Lekton',
    'Lemon' => 'Lemon',

    'Libre Baskerville' => 'Libre Baskerville',
    'Life Savers' => 'Life Savers',
    'Lilita One' => 'Lilita One',
    'Limelight' => 'Limelight',
    'Linden Hill' => 'Linden Hill',
    'Lobster' => 'Lobster',
    'Lobster Two' => 'Lobster Two',
    'Londrina Outline' => 'Londrina Outline',
    'Londrina Shadow' => 'Londrina Shadow',
    'Londrina Sketch' => 'Londrina Sketch',
    'Londrina Solid' => 'Londrina Solid',
    'Lora' => 'Lora',
    'Love Ya Like A Sister' => 'Love Ya Like A Sister',
    'Loved by the King' => 'Loved by the King',
    'Lovers Quarrel' => 'Lovers Quarrel',
    'Lucida Sans Unicode' => 'Lucida Sans Unicode',
    'Luckiest Guy' => 'Luckiest Guy',
    'Lusitana' => 'Lusitana',
    'Lustria' => 'Lustria',
    'Macondo' => 'Macondo',
    'Macondo Swash Caps' => 'Macondo Swash Caps',
    'Magra' => 'Magra',
    'Maiden Orange' => 'Maiden Orange',
    'Mallanna' => 'Mallanna',
    'Mandali' => 'Mandali',
    'Mako' => 'Mako',
    'Marcellus' => 'Marcellus',
    'Marcellus SC' => 'Marcellus SC',
    'Marck Script' => 'Marck Script',
    'Margarine' => 'Margarine',
    'Marko One' => 'Marko One',
    'Marmelad' => 'Marmelad',
    'Marvel' => 'Marvel',
    'Martel' => 'Martel',
    'Martel Sans' => 'Martel Sans',
    'Mate' => 'Mate',
    'Mate SC' => 'Mate SC',
    'Maven Pro' => 'Maven Pro',
    'McLaren' => 'McLaren',
    'Meddon' => 'Meddon',
    'MedievalSharp' => 'MedievalSharp',
    'Medula One' => 'Medula One',
    'Megrim' => 'Megrim',
    'Meie Script' => 'Meie Script',
    'Merienda' => 'Merienda',
    'Merienda One' => 'Merienda One',
    'Merriweather' => 'Merriweather',
    'Metal' => 'Metal',
    'Metal Mania' => 'Metal Mania',
    'Metamorphous' => 'Metamorphous',
    'Metrophobic' => 'Metrophobic',
    'Michroma' => 'Michroma',
    'Milonga' => 'Milonga',
    'Miltonian' => 'Miltonian',
    'Miltonian Tattoo' => 'Miltonian Tattoo',
    'Miniver' => 'Miniver',
    'Miss Fajardose' => 'Miss Fajardose',
    'Miss Saint Delafield' => 'Miss Saint Delafield',
    'Modak' => 'Modak',
    'Modern Antiqua' => 'Modern Antiqua',
    'Molengo' => 'Molengo',
    'Molle' => 'Molle',
    'Moulpali' => 'Moulpali',
    'Monda' => 'Monda',
    'Monofett' => 'Monofett',
    'Monoton' => 'Monoton',
    'Monsieur La Doulaise' => 'Monsieur La Doulaise',
    'Montaga' => 'Montaga',
    'Montez' => 'Montez',
    'Montserrat' => 'Montserrat',
    'Montserrat Alternates' => 'Montserrat Alternates',
    'Montserrat Subrayada' => 'Montserrat Subrayada',
    'Mountains of Christmas' => 'Mountains of Christmas',
    'Mouse Memoirs' => 'Mouse Memoirs',
    'Moul' => 'Moul',
    'Mr Bedford' => 'Mr Bedford',
    'Mr Bedfort' => 'Mr Bedfort',
    'Mr Dafoe' => 'Mr Dafoe',
    'Mr De Haviland' => 'Mr De Haviland',
    'Mrs Saint Delafield' => 'Mrs Saint Delafield',
    'Mrs Sheppards' => 'Mrs Sheppards',
    'Muli' => 'Muli',
    'Mystery Quest' => 'Mystery Quest',
    'Neucha' => 'Neucha',
    'Neuton' => 'Neuton',
    'New Rocker' => 'New Rocker',
    'News Cycle' => 'News Cycle',
    'Niconne' => 'Niconne',
    'Nixie One' => 'Nixie One',
    'Nobile' => 'Nobile',
    'Nokora' => 'Nokora',
    'Norican' => 'Norican',
    'Nosifer' => 'Nosifer',
    'Nosifer Caps' => 'Nosifer Caps',
    'Nova Mono' => 'Nova Mono',
    'Noticia Text' => 'Noticia Text',
    'Noto Sans' => 'Noto Sans',
    'Noto Serif' => 'Noto Serif',
    'Nova Round' => 'Nova Round',
    'Numans' => 'Numans',
    'Nunito' => 'Nunito',
    'NTR' => 'NTR',
    'Offside' => 'Offside',
    'Oldenburg' => 'Oldenburg',
    'Oleo Script' => 'Oleo Script',
    'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
    'Open Sans' => 'Open Sans',
    'Open Sans Condensed' => 'Open Sans Condensed',
    'Oranienbaum' => 'Oranienbaum',
    'Orbitron' => 'Orbitron',
    'Odor Mean Chey' => 'Odor Mean Chey',
    'Oregano' => 'Oregano',
    'Orienta' => 'Orienta',
    'Original Surfer' => 'Original Surfer',
    'Oswald' => 'Oswald',
    'Over the Rainbow' => 'Over the Rainbow',
    'Overlock' => 'Overlock',
    'Overlock SC' => 'Overlock SC',
    'Ovo' => 'Ovo',
    'Oxygen' => 'Oxygen',
    'Oxygen Mono' => 'Oxygen Mono',
    'Palanquin Dark' => 'Palanquin Dark',
    'Peddana' => 'Peddana',
    'Poppins' => 'Poppins',
    'PT Mono' => 'PT Mono',
    'PT Sans' => 'PT Sans',
    'PT Sans Caption' => 'PT Sans Caption',
    'PT Sans Narrow' => 'PT Sans Narrow',
    'PT Serif' => 'PT Serif',
    'PT Serif Caption' => 'PT Serif Caption',
    'Pacifico' => 'Pacifico',
    'Paprika' => 'Paprika',
    'Parisienne' => 'Parisienne',
    'Passero One' => 'Passero One',
    'Passion One' => 'Passion One',
    'Patrick Hand' => 'Patrick Hand',
    'Patrick Hand SC' => 'Patrick Hand SC',
    'Patua One' => 'Patua One',
    'Paytone One' => 'Paytone One',
    'Peralta' => 'Peralta',
    'Permanent Marker' => 'Permanent Marker',
    'Petit Formal Script' => 'Petit Formal Script',
    'Petrona' => 'Petrona',
    'Philosopher' => 'Philosopher',
    'Piedra' => 'Piedra',
    'Pinyon Script' => 'Pinyon Script',
    'Pirata One' => 'Pirata One',
    'Plaster' => 'Plaster',
    'Palatino Linotype' => 'Palatino Linotype',
    'Play' => 'Play',
    'Playball' => 'Playball',
    'Playfair Display' => 'Playfair Display',
    'Playfair Display SC' => 'Playfair Display SC',
    'Podkova' => 'Podkova',
    'Poiret One' => 'Poiret One',
    'Poller One' => 'Poller One',
    'Poly' => 'Poly',
    'Pompiere' => 'Pompiere',
    'Pontano Sans' => 'Pontano Sans',
    'Port Lligat Sans' => 'Port Lligat Sans',
    'Port Lligat Slab' => 'Port Lligat Slab',
    'Prata' => 'Prata',
    'Pragati Narrow' => 'Pragati Narrow',
    'Preahvihear' => 'Preahvihear',
    'Press Start 2P' => 'Press Start 2P',
    'Princess Sofia' => 'Princess Sofia',
    'Prociono' => 'Prociono',
    'Prosto One' => 'Prosto One',
    'Puritan' => 'Puritan',
    'Purple Purse' => 'Purple Purse',
    'Quando' => 'Quando',
    'Quantico' => 'Quantico',
    'Quattrocento' => 'Quattrocento',
    'Quattrocento Sans' => 'Quattrocento Sans',
    'Questrial' => 'Questrial',
    'Quicksand' => 'Quicksand',
    'Quintessential' => 'Quintessential',
    'Qwigley' => 'Qwigley',
    'Racing Sans One' => 'Racing Sans One',
    'Radley' => 'Radley',
    'Rajdhani' => 'Rajdhani',
    'Raleway Dots' => 'Raleway Dots',
    'Raleway' => 'Raleway',
    'Rambla' => 'Rambla',
    'Ramabhadra' => 'Ramabhadra',
    'Ramaraja' => 'Ramaraja',
    'Rammetto One' => 'Rammetto One',
    'Ranchers' => 'Ranchers',
    'Rancho' => 'Rancho',
    'Ranga' => 'Ranga',
    'Ravi Prakash' => 'Ravi Prakash',
    'Rationale' => 'Rationale',
    'Redressed' => 'Redressed',
    'Reenie Beanie' => 'Reenie Beanie',
    'Revalia' => 'Revalia',
    'Rhodium Libre' => 'Rhodium Libre',
    'Ribeye' => 'Ribeye',
    'Ribeye Marrow' => 'Ribeye Marrow',
    'Righteous' => 'Righteous',
    'Risque' => 'Risque',
    'Roboto' => 'Roboto',
    'Roboto Condensed' => 'Roboto Condensed',
    'Roboto Mono' => 'Roboto Mono',
    'Roboto Slab' => 'Roboto Slab',
    'Rochester' => 'Rochester',
    'Rock Salt' => 'Rock Salt',
    'Rokkitt' => 'Rokkitt',
    'Romanesco' => 'Romanesco',
    'Ropa Sans' => 'Ropa Sans',
    'Rosario' => 'Rosario',
    'Rosarivo' => 'Rosarivo',
    'Rouge Script' => 'Rouge Script',
    'Rozha One' => 'Rozha One',
    'Rubik' => 'Rubik',
    'Rubik One' => 'Rubik One',
    'Rubik Mono One' => 'Rubik Mono One',
    'Ruda' => 'Ruda',
    'Rufina' => 'Rufina',
    'Ruge Boogie' => 'Ruge Boogie',
    'Ruluko' => 'Ruluko',
    'Rum Raisin' => 'Rum Raisin',
    'Ruslan Display' => 'Ruslan Display',
    'Russo One' => 'Russo One',
    'Ruthie' => 'Ruthie',
    'Rye' => 'Rye',
    'Sacramento' => 'Sacramento',
    'Sail' => 'Sail',
    'Salsa' => 'Salsa',
    'Sanchez' => 'Sanchez',
    'Sancreek' => 'Sancreek',
    'Sahitya' => 'Sahitya',
    'Sansita One' => 'Sansita One',
    'Sarpanch' => 'Sarpanch',
    'Sarina' => 'Sarina',
    'Satisfy' => 'Satisfy',
    'Scada' => 'Scada',
    'Scheherazade' => 'Scheherazade',
    'Schoolbell' => 'Schoolbell',
    'Seaweed Script' => 'Seaweed Script',
    'Sarala' => 'Sarala',
    'Sevillana' => 'Sevillana',
    'Seymour One' => 'Seymour One',
    'Shadows Into Light' => 'Shadows Into Light',
    'Shadows Into Light Two' => 'Shadows Into Light Two',
    'Shanti' => 'Shanti',
    'Share' => 'Share',
    'Share Tech' => 'Share Tech',
    'Share Tech Mono' => 'Share Tech Mono',
    'Shojumaru' => 'Shojumaru',
    'Short Stack' => 'Short Stack',
    'Sigmar One' => 'Sigmar One',
    'Suranna' => 'Suranna',
    'Suravaram' => 'Suravaram',
    'Suwannaphum' => 'Suwannaphum',
    'Signika' => 'Signika',
    'Signika Negative' => 'Signika Negative',
    'Simonetta' => 'Simonetta',
    'Siemreap' => 'Siemreap',
    'Sirin Stencil' => 'Sirin Stencil',
    'Six Caps' => 'Six Caps',
    'Skranji' => 'Skranji',
    'Slackey' => 'Slackey',
    'Smokum' => 'Smokum',
    'Smythe' => 'Smythe',
    'Sniglet' => 'Sniglet',
    'Snippet' => 'Snippet',
    'Snowburst One' => 'Snowburst One',
    'Sofadi One' => 'Sofadi One',
    'Sofia' => 'Sofia',
    'Sonsie One' => 'Sonsie One',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Source Code Pro' => 'Source Code Pro',
    'Source Sans Pro' => 'Source Sans Pro',
    'Special I am one' => 'Special I am one',
    'Spicy Rice' => 'Spicy Rice',
    'Spinnaker' => 'Spinnaker',
    'Spirax' => 'Spirax',
    'Squada One' => 'Squada One',
    'Sree Krushnadevaraya' => 'Sree Krushnadevaraya',
    'Stalemate' => 'Stalemate',
    'Stalinist One' => 'Stalinist One',
    'Stardos Stencil' => 'Stardos Stencil',
    'Stint Ultra Condensed' => 'Stint Ultra Condensed',
    'Stint Ultra Expanded' => 'Stint Ultra Expanded',
    'Stoke' => 'Stoke',
    'Stoke' => 'Stoke',
    'Strait' => 'Strait',
    'Sura' => 'Sura',
    'Sumana' => 'Sumana',
    'Sue Ellen Francisco' => 'Sue Ellen Francisco',
    'Sunshiney' => 'Sunshiney',
    'Supermercado One' => 'Supermercado One',
    'Swanky and Moo Moo' => 'Swanky and Moo Moo',
    'Syncopate' => 'Syncopate',
    'Symbol' => 'Symbol',
    'Timmana' => 'Timmana',
    'Taprom' => 'Taprom',
    'Tangerine' => 'Tangerine',
    'Tahoma' => 'Tahoma',
    'Teko' => 'Teko',
    'Telex' => 'Telex',
    'Tenali Ramakrishna' => 'Tenali Ramakrishna',
    'Tenor Sans' => 'Tenor Sans',
    'Terminal Dosis' => 'Terminal Dosis',
    'Terminal Dosis Light' => 'Terminal Dosis Light',
    'Text Me One' => 'Text Me One',
    'The Girl Next Door' => 'The Girl Next Door',
    'Tienne' => 'Tienne',
    'Tillana' => 'Tillana',
    'Tinos' => 'Tinos',
    'Titan One' => 'Titan One',
    'Titillium Web' => 'Titillium Web',
    'Trade Winds' => 'Trade Winds',
    'Trebuchet MS' => 'Trebuchet MS',
    'Trocchi' => 'Trocchi',
    'Trochut' => 'Trochut',
    'Trykker' => 'Trykker',
    'Tulpen One' => 'Tulpen One',
    'Ubuntu' => 'Ubuntu',
    'Ubuntu Condensed' => 'Ubuntu Condensed',
    'Ubuntu Mono' => 'Ubuntu Mono',
    'Ultra' => 'Ultra',
    'Uncial Antiqua' => 'Uncial Antiqua',
    'Underdog' => 'Underdog',
    'Unica One' => 'Unica One',
    'UnifrakturCook' => 'UnifrakturCook',
    'UnifrakturMaguntia' => 'UnifrakturMaguntia',
    'Unkempt' => 'Unkempt',
    'Unlock' => 'Unlock',
    'Unna' => 'Unna',
    'VT323' => 'VT323',
    'Vampiro One' => 'Vampiro One',
    'Varela' => 'Varela',
    'Varela Round' => 'Varela Round',
    'Vast Shadow' => 'Vast Shadow',
    'Vesper Libre' => 'Vesper Libre',
    'Verdana' => 'Verdana',
    'Vibur' => 'Vibur',
    'Vidaloka' => 'Vidaloka',
    'Viga' => 'Viga',
    'Voces' => 'Voces',
    'Volkhov' => 'Volkhov',
    'Vollkorn' => 'Vollkorn',
    'Voltaire' => 'Voltaire',
    'Waiting for the Sunrise' => 'Waiting for the Sunrise',
    'Wallpoet' => 'Wallpoet',
    'Walter Turncoat' => 'Walter Turncoat',
    'Warnes' => 'Warnes',
    'Wellfleet' => 'Wellfleet',
    'Wendy One' => 'Wendy One',
    'Wire One' => 'Wire One',
    'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
    'Yantramanav' => 'Yantramanav',
    'Yellowtail' => 'Yellowtail',
    'Yeseva One' => 'Yeseva One',
    'Yesteryear' => 'Yesteryear',
    'Zeyada' => 'Zeyada'
  );

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	
	$options = array();
	$imagepath =  get_template_directory_uri() . '/images/';

	
	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(
		1 => array(
			'section_title'	=> '',
			'menutitle'		=> 'aboutmesection',
			'bgcolor' 		=> '#f8f8f8',
			'bgimage'		=> '',
			'class'			=> 'aboutmewrap',
			'content'		=> '[column_content type="one_half"]
			<h2>About Us</h2>
			Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id enim Suspendisse suscipit  ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.
			
			Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor enim Suspendisse suscipit . Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.
			
			<h3>Fitness Club Time</h3>			
			[office-hours icon="clock-o" days="Monday-Friday" time="06.00am-11.00pm"][office-hours icon="" days="Saturday" time="06.00am-11.00pm"][office-hours icon="" days="Sunday" time="06.00am-11.00pm"]

[/column_content]

[column_content type="one_half_last"]<img src="'.get_template_directory_uri().'/images/aboutme-thumb.jpg" />[/column_content]',
		),
		
		2 => array(
			'section_title'	=> '',
			'menutitle'		=> 'featureservices',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '[servicesbox color="#111111" bgcolor="#ffffff" image="'.get_template_directory_uri().'/images/services-icon-1.png" title="Fitness" description="Lorem ipsum dolor sit amet placerat facilisis felis miin sit amet placerat facilisis felis tempus. Eleifend pellentesque natoque faucibus magna felis miin tempusut etiam felis mi in tempus."][servicesbox color="#111111" bgcolor="#ffffff" image="'.get_template_directory_uri().'/images/services-icon-2.png" title="Yoga" description="Lorem ipsum dolor sit amet placerat facilisis felis miin sit amet placerat facilisis felis tempus. Eleifend pellentesque natoque faucibus magna felis miin tempusut etiam felis mi in tempus."][servicesbox color="#111111" bgcolor="#ffffff" image="'.get_template_directory_uri().'/images/services-icon-3.png" title="Weight Lifting" description="Lorem ipsum dolor sit amet placerat facilisis felis miin sit amet placerat facilisis felis tempus. Eleifend pellentesque natoque faucibus magna felis miin tempusut etiam felis mi in tempus."][servicesbox color="#111111" bgcolor="#ffffff" image="'.get_template_directory_uri().'/images/services-icon-4.png" title="Personal Massage" description="Lorem ipsum dolor sit amet placerat facilisis felis miin sit amet placerat facilisis felis tempus. Eleifend pellentesque natoque faucibus magna felis miin tempusut etiam felis mi in tempus."]',
		),
		
		3 => array(
			'section_title'	=> 'What We Offer',
			'menutitle'		=> 'ThemeFeaturd',
			'bgcolor' 		=> '#f3f2f7',
			'bgimage'		=> '',
			'class'			=> 'feature-wrap',
			'content'		=> '[subtitle color="#727272" size="15px" margin="0 0 50px 0" align="center" description="Suspendisse vel velit nulla. Phasellus tincidunt in nisl eu iaculis. Etiam at porttitor lacus vel velit nulla. Phasellus tincidunt in nisl eu iaculis. Etiam at porttitor  nisl eu iaculis Etiam at porttitor lacus vel velit nulla lacus"]
[column_content type="one_half"]<img src="'.get_template_directory_uri().'/images/services_thumb.jpg" alt="" />[/column_content][column_content type="one_half_last"][servingyou title="Boxing Workout" description="Eleifend pellentesque natoque faucibus magna felismiin ever tempusut etiam felis." image="'.get_template_directory_uri().'/images/servingyou1.png" url="#"][servingyou title="Crossfit" description="Eleifend pellentesque natoque faucibus magna felismiin ever tempusut etiam felis." image="'.get_template_directory_uri().'/images/servingyou2.png" url="#" class="last"][servingyou title="Stretching" description="Eleifend pellentesque natoque faucibus magna felismiin ever tempusut etiam felis." image="'.get_template_directory_uri().'/images/servingyou3.png" url="#"][servingyou title="Dancing" description="Eleifend pellentesque natoque faucibus magna felismiin ever tempusut etiam felis." image="'.get_template_directory_uri().'/images/servingyou4.png" url="#" class="last"][servingyou title="Aerobics" description="Eleifend pellentesque natoque faucibus magna felismiin ever tempusut etiam felis." image="'.get_template_directory_uri().'/images/servingyou5.png" url="#"][servingyou title="Pilates" description="Eleifend pellentesque natoque faucibus magna felismiin ever tempusut etiam felis." image="'.get_template_directory_uri().'/images/servingyou6.png" url="#" class="last"]
[/column_content]'
		),
		
		
		4 => array(
			'section_title'	=> 'Fitness Classes in this Summer',
			'menutitle'		=> 'promowraper',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/promotionbg.jpg',
			'class'			=> '',
			'content'		=> '<h3>Sign Up now and get <span>30%</span> Discount</h3>Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor.[button align="center" name="Sign Up Now" link="#" target=""] ',
		),
		 
		5 => array(
			'section_title'	=> 'Yoga Services',
			'menutitle'		=> 'populararea',
			'bgcolor' 		=> '#f2f1f1',
			'bgimage'		=> '',
			'class'			=> 'popularwrap',
			'content'		=> '[column_content type="one_fourth"]
	<a href="#" class="hvr-rectangle-out"><img src="'.get_template_directory_uri().'/images/defaultimg01.jpg"/></a>
	<h3 class="yogatitle">Meditation Practice</h3>
	<p class="desc">Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.</p>
[/column_content]

[column_content type="one_fourth"]
	<a href="#" class="hvr-rectangle-out"><img src="'.get_template_directory_uri().'/images/defaultimg02.jpg"/></a>
	<h3 class="yogatitle">Healthy Daily Life</h3>
	<p class="desc">Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.</p>
[/column_content]

[column_content type="one_fourth"]
	<a href="#" class="hvr-rectangle-out"><img src="'.get_template_directory_uri().'/images/defaultimg03.jpg"/></a>
	<h3 class="yogatitle">Ashtanga Yoga</h3>
	<p class="desc">Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.</p>
[/column_content]

[column_content type="one_fourth_last"]
	<a href="#" class="hvr-rectangle-out"><img src="'.get_template_directory_uri().'/images/defaultimg04.jpg"/></a>
	<h3 class="yogatitle">Yoga Dance</h3>
	<p class="desc">Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.</p>
[/column_content]'
		),
		 
		 6 => array(
			'section_title'	=> 'Pricing Plan',
			'menutitle'		=> 'pricesection',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> get_template_directory_uri().'/images/pricingbg.jpg',
			'class'			=> 'pricewrap',
			'content'		=> '[pricing_table columns="4"]
	[price_column highlight="no" bgcolor=""]
		[price_header bgcolors="#0796D0"]Basic[/price_header]
		[price_row]Free Hand[/price_row]
		[price_row]Gym Fitness[/price_row]
		[price_row]Massage[/price_row]
		[price_row]x[/price_row]
		[price_row]x[/price_row]
		[price_row]x[/price_row]	
		[price_footer link="#1"]Details[/price_footer]
	[/price_column][price_column highlight="yes" bgcolor="#b24d1c"]
		[price_header bgcolors="#0796D0"]Premium[/price_header]
		[price_row]Free Hand[/price_row]
		[price_row]Gym Fitness[/price_row]
		[price_row]Massage[/price_row]
		[price_row]Yoga[/price_row]	
		[price_row]x[/price_row]
		[price_row]x[/price_row]	
		[price_footer link="#2"]Details[/price_footer]
	[/price_column][price_column highlight="no" bgcolor=""]
		[price_header bgcolors="#0796D0"]Professional[/price_header]
		[price_row]Free Hand[/price_row]
		[price_row]Gym Fitness[/price_row]
		[price_row]Massage[/price_row]
		[price_row]Yoga[/price_row]
		[price_row]Running[/price_row]
		[price_row]x[/price_row]	
		[price_footer link="#3"]Details[/price_footer]
	[/price_column][price_column highlight="no" bgcolor=""]
		[price_header bgcolors="#0796D0"]Expert[/price_header]
		[price_row]Free Hand[/price_row]
		[price_row]Gym Fitness[/price_row]
		[price_row]Massage[/price_row]
		[price_row]Yoga[/price_row]
		[price_row]Running[/price_row]
		[price_row]Body Building[/price_row]		
		[price_footer link="#4"]Details[/price_footer]
	[/price_column]
[/pricing_table]',
		 ),	
		 7 => array(
			'section_title'	=> 'Our Trainers',
			'menutitle'		=> 'teamsection',
			'bgcolor' 		=> '#f5f4f4',
			'bgimage'		=> '',
			'class'			=> 'serviceswrap',
			'content'		=> '[our-trainers show="4"] ',
		),	
		
		
		8 => array(
			'section_title'	=> '',
			'menutitle'		=> 'ourskills',
			'bgcolor' 		=> '',
			'bgimage'		=>  get_template_directory_uri().'/images/counterbg.jpg',
			'class'			=> 'skillwrap',
			'content'		=> '[counter iconname="group" value="125" title="Trainers"][counter iconname="user-secret" value="4215" title="Members"][counter iconname="list" value="215" title="Equipments"] [counter iconname="graduation-cap" value="17" title="Fitness Degrees"]'
		),
		
		
		9 => array(
			'section_title'	=> 'Latest News',
			'menutitle'		=> 'newswraper',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'newswrap',
			'content'		=> '[latest-news showposts="4" comment="show" date="show" author="show"]',
		),		

		
		10 => array(
			'section_title'	=> 'Clients Testimonials',
			'menutitle'		=> 'testimonialswrap',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/testimonialsbg.jpg',
			'class'			=> 'tmnlWrap',
			'content'		=> '[testimonials]'
		),
		
		11 => array(
			'section_title'	=> 'Our Gallery',
			'menutitle'		=> 'home-gallery',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'gallerywrap',
			'content'		=> '[photogallery show="8" filter="true"] [button align="center" name="View Gallery" link="#" target=""]',
		),		

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'powerclub'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'powerclub'),
		'desc' => __('Upload your main logo here', 'powerclub'),
		'id' => 'logo',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc' => __('manage your logo height', 'powerclub'),
		'id' => 'logoheight',
		'std' => '55px',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'powerclub'),		
		'desc'	=> __('Check To hide site title and description', 'powerclub'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> '');			
		
	$options[] = array(
		'name' => __('Sticky Header', 'powerclub'),
		'desc' => __('Check this to disable sticky header on scroll', 'powerclub'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Disable Animation', 'powerclub'),
		'desc' => __('Check this to disable animation on scroll', 'powerclub'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');					

	$options[] = array(
		'name' => __('Custom CSS', 'powerclub'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'powerclub'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Header Top Social Icons', 'powerclub'),
		'desc' => __('Edit select social icons for header top', 'powerclub'),
		'id' => 'headersocial',
		'std' => ' [social_area] [social icon="facebook" link="#"] [social icon="twitter" link="#"] [social icon="google-plus" link="#"] [social icon="linkedin" link="#"][/social_area]',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Header Top Info', 'powerclub'),
		'desc' => __('Edit header info from here. NOTE: Icon name should be in lowercase without space.(exa.phone) More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/', 'powerclub'),
		'id' => 'headerinfo',
		'std' => '<i class="fa fa-phone"></i> <span class="phno">+11 123 456 7890</span> <i class="fa fa-map-marker"></i>1600 Demo Address Parkway Mountain View, CA 94043 ',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Disable Header top Strip', 'powerclub'),
		'desc' => __('Check to disable header top contact info and social icons', 'powerclub'),
		'id' => 'headtopstrip',
		'std' => '',
		'type' => 'checkbox');		
		
	// font family start 		
	$options[] = array(
		'name' => __('Font Faces', 'powerclub'),
		'desc' => __('Select font for the body text', 'powerclub'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'Open Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'powerclub'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'powerclub'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for all heading tag.', 'powerclub'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
			
	$options[] = array(
		'desc' => __('Select font for Slide title', 'powerclub'),
		'id' => 'slidetitlefontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	
		
	$options[] = array(
		'desc' => __('Select font for Slide Description', 'powerclub'),
		'id' => 'slidedesfontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	

		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'powerclub'),
		'desc' => __('Select font size for body text', 'powerclub'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'powerclub'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '40px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'powerclub'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '14px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'powerclub'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '34px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'powerclub'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );	

	$options[] = array(
		'desc' => __('Select h1 font size', 'powerclub'),
		'id' => 'h1fontsize',
		'std' => '32px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h2 font size', 'powerclub'),
		'id' => 'h2fontsize',
		'std' => '28px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h3 font size', 'powerclub'),
		'id' => 'h3fontsize',
		'std' => '18px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h4 font size', 'powerclub'),
		'id' => 'h4fontsize',
		'std' => '22px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h5 font size', 'powerclub'),
		'id' => 'h5fontsize',
		'std' => '20px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h6 font size', 'powerclub'),
		'id' => 'h6fontsize',
		'std' => '14px',
		'type' => 'select',
		'options' => $font_sizes);


	// font colors start

	$options[] = array(
		'name' => __('Font Colors', 'powerclub'),
		'desc' => __('Select font color for the body text', 'powerclub'),
		'id' => 'bodyfontcolor',
		'std' => '#555555',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'powerclub'),
		'id' => 'logofontcolor',
		'std' => '#0796d0',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for logo tagline', 'powerclub'),
		'id' => 'logotaglinecolor',
		'std' => '#828181',
		'type' => 'color');
		
	

	$options[] = array(
		'desc' => __('Select font color for social icons', 'powerclub'),
		'id' => 'socialfontcolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font hover color for social icons', 'powerclub'),
		'id' => 'socialfonthvcolor',
		'std' => '#cccccc',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'powerclub'),
		'id' => 'sectitlecolor',
		'std' => '#515151',
		'type' => 'color');	
		
	
	$options[] = array(
		'desc' => __('Select font color for navigation', 'powerclub'),
		'id' => 'navfontcolor',
		'std' => '#515151',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'powerclub'),
		'id' => 'navhovercolor',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'powerclub'),
		'id' => 'wdgttitleccolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'powerclub'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'powerclub'),
		'id' => 'footdesccolor',
		'std' => '#595959',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer menu ', 'powerclub'),
		'id' => 'footermenucolor',
		'std' => '#0796d0',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font hover color for footer menu ', 'powerclub'),
		'id' => 'footermenucurrent',
		'std' => '#8e8d8d',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'powerclub'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'powerclub'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'powerclub'),
		'id' => 'linkcolor',
		'std' => '#0796d0',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for links / anchor tags', 'powerclub'),
		'id' => 'linkhovercolor',
		'std' => '#272727',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'powerclub'),
		'id' => 'sidebarfontcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'powerclub'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#0796d0',
		'type' => 'color');			
			
	
	$options[] = array(
		'desc' => __('Select font color for footer links', 'powerclub'),
		'id' => 'copylinks',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer links', 'powerclub'),
		'id' => 'copylinkshover',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h1 font color', 'powerclub'),
		'id' => 'h1fontcolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select h2 font color', 'powerclub'),
		'id' => 'h2fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h3 font color', 'powerclub'),
		'id' => 'h3fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h4 font color', 'powerclub'),
		'id' => 'h4fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h5 font color', 'powerclub'),
		'id' => 'h5fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h6 font color', 'powerclub'),
		'id' => 'h6fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for last word colorful for title', 'powerclub'),
		'id' => 'lastwordcolor',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle box', 'powerclub'),
		'id' => 'countercirclecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle number', 'powerclub'),
		'id' => 'countercirclenumber',
		'std' => '#0796d0',
		'type' => 'color');	

		
	$options[] = array(
		'desc' => __('Select font color for testimonials title', 'powerclub'),
		'id' => 'testimonialtitle',
		'std' => '#ffffff',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for testimonials decription', 'powerclub'),
		'id' => 'testimonialdesc',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer social icons', 'powerclub'),
		'id' => 'footsocialcolor',
		'std' => '#303030',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer social icons', 'powerclub'),
		'id' => 'footsocialhvcolor',
		'std' => '#0796d0',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select font color for header top', 'powerclub'),
		'id' => 'headertopcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for top four services boxes', 'powerclub'),
		'id' => 'top4boxeshovercolor',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for what we offer services section', 'powerclub'),
		'id' => 'whatweoffertitle',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select font color for fitness offer rate', 'powerclub'),
		'id' => 'fitnessofferspan',
		'std' => '#0796d0',
		'type' => 'color');			
					
		
	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'powerclub'),	
		'desc' => __('Select background color for header', 'powerclub'),
		'id' => 'headerbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select background color for header nav dropdown', 'powerclub'),
		'id' => 'navdpbgcolor',
		'std' => '#ffffff',
		'type' => 'color');
	

	$options[] = array(
		'desc' => __('Select background color for footer', 'powerclub'),
		'id' => 'footerbgcolor',
		'std' => '#1a191a',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'powerclub'),
		'id' => 'copybgcolor',
		'std' => '#111111',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'powerclub'),
		'id' => 'togglemenu',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for our team expert boxes', 'powerclub'),
		'id' => 'teambgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for header top', 'powerclub'),
		'id' => 'headertopbgcolor',
		'std' => '#0796D0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover and active color for photo gallery', 'powerclub'),
		'id' => 'galleryactivebgcolor',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for top page boxes thumbnail', 'powerclub'),
		'id' => 'pageboxedbgcolor',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for yoga services section', 'powerclub'),
		'id' => 'yogaservicesbgcolor',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for team member box', 'powerclub'),
		'id' => 'teamboxbgcolor',
		'std' => '#0796d0',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background hover color for latest news box', 'powerclub'),
		'id' => 'newsboxbgcolor',
		'std' => '#0796d0',
		'type' => 'color');	

	// Border colors
	$options[] = array(
		'name' => __('Border Colors', 'powerclub'),	
		'desc' => __('Select border color for All', 'powerclub'),
		'id' => 'allbdcolor',
		'std' => '#0796d0',
		'type' => 'color');
			
	$options[] = array(	
		'desc' => __('Select border color for footer posts', 'powerclub'),
		'id' => 'footerpostborder',
		'std' => '#5e6162',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'powerclub'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for our staff degignation', 'powerclub'),
		'id' => 'teamborder',
		'std' => '#EAEAEA',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget title', 'powerclub'),
		'id' => 'widgettitleborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget box', 'powerclub'),
		'id' => 'widgetboxborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for third section title underline', 'powerclub'),
		'id' => 'thirdsectionborder',
		'std' => '#444444',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for what we offer services box underline', 'powerclub'),
		'id' => 'wtweofferunderline',
		'std' => '#dddddd',
		'type' => 'color');		
		
	$options[] = array(			
		'desc' => __('Select border color for footer all underline', 'powerclub'),
		'id' => 'footerallborder',
		'std' => '#303030',
		'type' => 'color');	
		
					
		
		

	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'powerclub'),		
		'desc' => __('Select background color for default button', 'powerclub'),
		'id' => 'btnbgcolor',
		'std' => '#0796d0',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background hover color for default button', 'powerclub'),
		'id' => 'btnbghvcolor',
		'std' => '#424242',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color default button', 'powerclub'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for default button', 'powerclub'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');

	// Slider Caption colors	
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'powerclub'),			
		'desc' => __('Select font color for slider title', 'powerclub'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'powerclub'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'powerclub'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '60px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'powerclub'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'powerclub'),
		'desc' => __('Select background color for slider pager', 'powerclub'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background active color for slider pager', 'powerclub'),
		'id' => 'sldpagehvbg',
		'std' => '#0796d0',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select Border color for slider pager', 'powerclub'),
		'id' => 'sldpagehvbd',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'name' => __('Blog Single Layout', 'powerclub'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'powerclub'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );
	
	$options[] = array(
		'name' => __('Read More Button Text', 'powerclub'),	
		'desc' => __('change read more button text for our latest news posts ', 'powerclub'),
		'id' => 'blogpostreadmoretext',
		'std' => 'Read More...',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Change Show All Button text for photo gallery section', 'powerclub'),
		'id' => 'galleryshowallbtn',
		'std' => 'Show All',
		'type' => 'text');			
	
	$options[] = array(
		'name' => __('Excerpt Length', 'powerclub'),	
		'desc' => __('select excerpt length for our trainers ', 'powerclub'),
		'id' => 'teamexcerptlength',
		'std' => '20',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('select excerpt length for latest news posts ', 'powerclub'),
		'id' => 'newsexcerptlength',
		'std' => '15',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('select excerpt length for testimonials ', 'powerclub'),
		'id' => 'testimonialsexcerptlength',
		'std' => '45',
		'type' => 'text');	
		
	$options[] = array(	
		'name' => __('Testimonials Rotating Speed', 'powerclub'),	
		'desc' => __('manage testimonials rotating speed.', 'powerclub'),
		'id' => 'testimonialsrotatingspeed',
		'std' => '8000',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('True/False Auto play Testimonials.','powerclub'),
		'id' => 'testimonialsautoplay',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'True', 'false'=>'False'));									
		

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'powerclub'),
		'type' => 'heading');	
	
	$options[] = array(	
		'name' => __('Services four Boxes Section', 'powerclub'),
		'desc'	=> __('first Services box for frontpage section','powerclub'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for first box.', 'powerclub'),
		'id' => 'boximg1',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section','powerclub'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for second box.', 'powerclub'),
		'id' => 'boximg2',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section','powerclub'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for third box.', 'powerclub'),
		'id' => 'boximg3',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Fourth Services box for frontpage section','powerclub'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for fourth box.', 'powerclub'),
		'id' => 'boximg4',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('Fifth Services box for frontpage section','powerclub'),
		'id' 	=> 'box5',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for fifth box.', 'powerclub'),
		'id' => 'boximg5',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');		
		
	$options[] = array(	
		'desc' => __('Change read more button text for  top services four boxes ', 'powerclub'),
		'id' => 'readmorebutton',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for services four boxes section', 'powerclub'),
		'id' => 'pageboxlength',
		'std' => '20',
		'type' => 'text');			
	
	$options[] = array(			
			'desc'	=> __('Check to hide above our services four column section', 'powerclub'),
			'id'	=> 'hidefourbxsec',
			'type'	=> 'checkbox',
			'std'	=> '');
	
	$options[] = array(
		'name' => __('Number of Sections', 'powerclub'),
		'desc' => __('Select number of sections', 'powerclub'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '11',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 11 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'powerclub'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'powerclub'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'powerclub'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.', 'powerclub'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'powerclub'),
			'desc' => __('Select background color for section', 'powerclub'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'powerclub'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'powerclub'),
			'desc' => __('Set class for this section.', 'powerclub'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'powerclub'),
			'desc'	=> __('Check to hide this section', 'powerclub'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'powerclub'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'powerclub'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'powerclub'),
		'desc' => __('Upload inner page banner for site', 'powerclub'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');
		
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'powerclub'),
		'desc' => __('Enter here your slider shortcode without php tag', 'powerclub'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'powerclub'),
		'desc' => __('Select slider effect.','powerclub'),
		'id' => 'slideefect',
		'std' => 'random',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'powerclub'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'powerclub'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'powerclub'),
		'desc' => __('Hide/Show Direction Naviagtion of slider.','powerclub'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','powerclub'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','powerclub'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
	$options[] = array(
		'name' => __('Slider Image 1', 'powerclub'),
		'desc' => __('First Slide', 'powerclub'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'powerclub'),
		'id' => 'slidetitle1',
		'std' => 'Get Ready To Transform Your Life',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc1',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton1',
		'std' => '',
		'type' => 'text');	

	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl1',
		'std' => '',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'powerclub'),
		'desc' => __('Second Slide', 'powerclub'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'powerclub'),
		'id' => 'slidetitle2',
		'std' => 'Build Your Body Strong',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc2',
		'std' => '',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton2',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl2',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 3', 'powerclub'),
		'desc' => __('Third Slide', 'powerclub'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'powerclub'),
		'id' => 'slidetitle3',
		'std' => 'Best Set Of Fitness Equipments',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc3',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton3',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl3',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 4', 'powerclub'),
		'desc' => __('Third Slide', 'powerclub'),
		'id' => 'slide4',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider4.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'powerclub'),
		'id' => 'slidetitle4',
		'std' => 'Body & Mind In Perfect Balance',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'powerclub'),
		'desc' => __('Fifth Slide', 'powerclub'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'powerclub'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'powerclub'),
		'desc' => __('Sixth Slide', 'powerclub'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 6', 'powerclub'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'powerclub'),
		'desc' => __('Seventh Slide', 'powerclub'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'powerclub'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'powerclub'),
		'desc' => __('Eighth Slide', 'powerclub'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'powerclub'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'powerclub'),
		'desc' => __('Ninth Slide', 'powerclub'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'powerclub'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'powerclub'),
		'desc' => __('Tenth Slide', 'powerclub'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'powerclub'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'powerclub'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'powerclub'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'powerclub'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');
	

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'powerclub'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'powerclub'),
		'desc' => __('footer Select layout. eg:Column, 1, 2, 3 and 4', 'powerclub'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );		
				
	$options[] = array(
		'name' => __('Footer About Us', 'powerclub'),
		'desc' => __('abput us text title for footer', 'powerclub'),
		'id' => 'abouttitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About Us Description', 'powerclub'),
		'desc' => __('abput us text description for footer', 'powerclub'),
		'id' => 'aboutusdescription',
		'std' => '<p>Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.</br > </br >Donec ut ex ac nulla sapien mauris, vitae sodales tellus suspendisse suscipit velit id ultricies auctor.</p>',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Menu Title', 'powerclub'),
		'desc' => __('footer menu title.', 'powerclub'),
		'id' => 'footermenutitle',
		'std' => 'Footer Menu',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Latest Posts Title', 'powerclub'),
		'desc' => __('Footer latest posts title.', 'powerclub'),
		'id' => 'letestpoststitle',
		'std' => 'Latest Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Get in Touch', 'powerclub'),
		'desc' => __('Add footer get in touch title here', 'powerclub'),
		'id' => 'contacttitle',
		'std' => 'Get in touch',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'powerclub'),
		'id' => 'address',
		'std' => 'No 1123, Sky Tower, New York, USA',
		'type' => 'textarea');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'powerclub'),
		'id' => 'phone',
		'std' => '+844 123 456 78',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add fax number here.', 'powerclub'),
		'id' => 'fax',
		'std' => '+844 123 456 79',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Add email address here.', 'powerclub'),
		'id' => 'email',
		'std' => 'info@yourdomain.com',
		'type' => 'text');
		
		
	$options[] = array(
		'name' => __('Footer Social Icons', 'powerclub'),
		'desc' => __('social icons for footer', 'powerclub'),
		'id' => 'footersocialicon',
		'std' => '[social_area]
			[social icon="facebook" link="#"]
			[social icon="twitter" link="#"]
			[social icon="linkedin" link="#"]
			[social icon="google-plus" link="#"]
		[/social_area]
		',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Copyright', 'powerclub'),
		'desc' => __('Copyright Text for your site.', 'powerclub'),
		'id' => 'copytext',
		'std' => '&copy; 2017 <a href="#">Power Club </a>. All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'powerclub'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('https://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footre Back to Top Button', 'powerclub'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'powerclub'),
		'type' => 'heading');	
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'powerclub'),
		'desc' => __('[photogallery filter="false"]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Testimonials', 'powerclub'),
		'desc' => __('[testimonials]', 'powerclub'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Contact Form', 'powerclub'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'powerclub'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Our Trainer', 'powerclub'),
		'desc' => __('[our-trainers show="4"]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Counter', 'powerclub'),
		'desc' => __('[counter iconname="group" value="1099" title="Our Trainer"][counter iconname="gift" value="9560" title="Our Visitor"][counter iconname="list" value="9560" title="Our Candidate List"] [counter iconname="graduation-cap" value="560" title="Our Awards"]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Latest News', 'powerclub'),
		'desc' => __('[latest-news showposts="4" comment="show" date="show" author="hide"] and all [latest-news]', 'powerclub'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Custom Button', 'powerclub'),
		'desc' => __('[button align="center" name="View Gallery" link="#" target=""]', 'powerclub'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Search Form', 'powerclub'),
		'desc' => __('[searchform]', 'powerclub'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'powerclub'),
		'desc' => __('[social_area]<br />
			[social icon="facebook" link="#"]<br />
			[social icon="twitter" link="#"]<br />
			[social icon="linkedin" link="#"]<br />
			[social icon="google-plus" link="#"]<br />
		[/social_area]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Sub Title', 'powerclub'),
		'desc' => __('[subtitle color="#727272" size="15px" margin="0 0 50px 0" align="center" description="enter here short description"]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Features Services', 'powerclub'),
		'desc' => __('[servingyou title="title here" description="description here" image="image url with http:" url="#"]
[servingyou title="title here" description="description here" image="image url with http:" url="#" class="last"]
[servingyou title="title here" description="description here" image="image url with http:" url="#"]
[servingyou title="title here" description="description here" image="image url with http:" url="#" class="last"]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Color Boxes Services', 'powerclub'),
		'desc' => __('[servicesbox color="#ffffff" bgcolor="#00aadd" image="image url with http:" title="title here" description="description here"]
[servicesbox color="#ffffff" bgcolor="#00aadd" image="image url with http:" title="title here" description="description here"]
[servicesbox color="#ffffff" bgcolor="#00aadd" image="image url with http:" title="title here" description="description here"]
[servicesbox color="#ffffff" bgcolor="#00aadd" image="image url with http:" title="title here" description="description here"]', 'powerclub'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Time Table', 'powerclub'),
		'desc' => __('[office-hours icon="clock-o" days="Monday-Friday" time="06.00am-11.00pm"][office-hours icon="" days="Saturday" time="06.00am-11.00pm"][office-hours icon="" days="Sunday" time="06.00am-11.00pm"]', 'powerclub'),
		'type' => 'info');		
		
	$options[] = array(
		'name' => __('Our Pricing Table', 'powerclub'),
		'desc' => __('[pricing_table columns="4"]
	[price_column highlight="no" bgcolor=""]
		[price_header bgcolors="#0796D0"]Basic[/price_header]
		[price_row]First Best Offer[/price_row]
		[price_row]Second Best Offer[/price_row]
		[price_row]Third Best Offer[/price_row]
		[price_row]Fourth Best Offer[/price_row]	
		[price_footer link="#1"]Details[/price_footer]
	[/price_column][price_column highlight="yes" bgcolor="#b24d1c"]
		[price_header bgcolors="#0796D0"]Standard[/price_header]
		[price_row]First Best Offer[/price_row]
		[price_row]Second Best Offer[/price_row]
		[price_row]Third Best Offer[/price_row]
		[price_row]Fourth Best Offer[/price_row]		
		[price_footer link="#2"]Details[/price_footer]
	[/price_column][price_column highlight="no" bgcolor=""]
		[price_header bgcolors="#0796D0"]Premium[/price_header]
		[price_row]First Best Offer[/price_row]
		[price_row]Second Best Offer[/price_row]
		[price_row]Third Best Offer[/price_row]
		[price_row]Fourth Best Offer[/price_row]	
		[price_footer link="#3"]Details[/price_footer]
	[/price_column][price_column highlight="no" bgcolor=""]
		[price_header bgcolors="#0796D0"]Expert[/price_header]
		[price_row]First Best Offer[/price_row]
		[price_row]Second Best Offer[/price_row]
		[price_row]Third Best Offer[/price_row]
		[price_row]Fourth Best Offer[/price_row]		
		[price_footer link="#4"]Details[/price_footer]
	[/price_column]
[/pricing_table]', 'powerclub'),
		'type' => 'info');		

	$options[] = array(
		'name' => __('2 Column Content', 'powerclub'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'powerclub'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'powerclub'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'powerclub'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'powerclub'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'powerclub'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'powerclub'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'powerclub'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Tabs', 'powerclub'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'powerclub'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'powerclub'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'powerclub'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'powerclub'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'powerclub'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Clear', 'powerclub'),
		'desc' => __('<pre>
[clear]
</pre>', 'powerclub'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'powerclub'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'powerclub'),
		'type' => 'info');
	
	$options[] = array(
		'name' => __('Scroll to Top', 'powerclub'),
		'desc' => __('[back-to-top] 
', 'powerclub'),
		'type' => 'info');	
				

	// Support					
	$options[] = array(
		'name' => __('Our Themes', 'powerclub'),
		'type' => 'heading');

	$options[] = array(
		'desc' => __('Grace Powerclub WordPress theme has been Designed and Created by <a href="'.esc_url('http://gracethemes.com/').'" target="_blank">Grace Themes</a>', 'powerclub'),
		'type' => 'info');	

	 $options[] = array(
		'desc' => __('<a href="'.esc_url('http://gracethemes.com/').'" target="_blank"><img src="'.get_template_directory_uri().'/images/themesbunch.jpg"></a>', 'powerclub'),
		'type' => 'info');	

	return $options;
}